angular.module("bluetoothController", ["ionic", "services", "tools"]).controller("BluetoothScanerCtrl", ["$scope", "Tools", "psisServices", "ServerConfig", "lruPersistCache", "OrderType", "$filter", "$ionicPopup", "$ionicPopover", "lbSpinnerDialog", "$timeout", "$rootScope", "$window", function($scope, dataAndEvents, deepDataAndEvents, ignoreMethodDoesntExist, textAlt, keepData, opt_attributes, matcherFunction, execResult, loading, ready, msg, $window) {
  /** @type {Array} */
  $scope.foundDevices = [];
  /**
   * @param {Function} connection
   * @return {undefined}
   */
  $scope.connect = function(connection) {
    if (window.plugins) {
      if (BC) {
        BC.Bluetooth.StopScan();
        loading.show();
        msg.bluethoothScaner = BC.bluetooth.devices[connection.deviceAddress];
        if (ionic.Platform.isAndroid()) {
          msg.bluethoothScaner.connect(function() {
            dataAndEvents.toastShow("蓝牙扫码枪连接成功");
            $window.localStorage.blueScaner = connection.deviceAddress;
            $scope.refreshFoundDevices();
            $scope.goBack();
          }, function() {
            loading.hide();
            dataAndEvents.toastShow("蓝牙扫码枪连接失败");
          }, "00001101-0000-1000-8000-00805F9B34FB", true);
        } else {
          msg.bluethoothScaner.connect(function() {
            /**
             * @param {?} response
             * @return {undefined}
             */
            function connect(response) {
              dataAndEvents.toastShow("蓝牙扫码枪已断开连接");
              /** @type {Array} */
              response.services = [];
            }
            dataAndEvents.toastShow("蓝牙扫码枪连接成功");
            $scope.refreshFoundDevices();
            connection.addEventListener("devicedisconnected", connect);
          }, function() {
            loading.hide();
            dataAndEvents.toastShow("蓝牙扫码枪连接失败");
          });
        }
      }
    }
  };
  /**
   * @param {?} options
   * @param {?} event
   * @return {undefined}
   */
  $scope.disConnect = function(options, event) {
    if (event) {
      event.stopPropagation();
    }
    loading.show();
    var d = BC.bluetooth.devices[options.deviceAddress];
    d.disconnect(function() {
      $scope.refreshFoundDevices();
      dataAndEvents.toastShow("已断开与 " + (d.deviceName ? d.deviceName : "无名设备") + " 的连接");
      msg.bluethoothScaner = void 0;
      /** @type {string} */
      $window.localStorage.blueScaner = "";
      /** @type {Array} */
      options.services = [];
      console.log("disConnect ok");
    }, function() {
      $scope.refreshFoundDevices();
      console.log("disConnect error");
    });
  };
  /**
   * @param {Function} callback
   * @return {undefined}
   */
  $scope.pair = function(callback) {
    $scope.connect(callback);
  };
  /**
   * @return {undefined}
   */
  $scope.refreshFoundDevices = function() {
    ready(function() {
      $scope.foundDevices = BC.bluetooth.devices;
      loading.hide();
    }, 100);
  };
  /**
   * @return {undefined}
   */
  $scope.scanDevices = function() {
    if (window.plugins) {
      if (BC) {
        BC.Bluetooth.StopScan();
        loading.show();
        if (ionic.Platform.isAndroid()) {
          BC.Bluetooth.StartScan("Classical");
        } else {
          BC.Bluetooth.StartScan();
        }
        $scope.refreshFoundDevices();
      }
    }
  };
  $scope.$on("$ionicView.loaded", function() {
    /**
     * @param {Event} e
     * @return {undefined}
     */
    function onload(e) {
      e.target;
      ready(function() {
        $scope.foundDevices = BC.bluetooth.devices;
      }, 500);
    }
    /**
     * @return {undefined}
     */
    function completed() {
      if (BC.bluetooth.isopen) {
        $scope.foundDevices = BC.bluetooth.devices;
      } else {
        ready(function() {
          /** @type {Array} */
          $scope.foundDevices = [];
        }, 100);
        dataAndEvents.toastShow("蓝牙已经关闭");
      }
    }
    if (window.plugins) {
      if (BC) {
        BC.bluetooth.addEventListener("newdevice", onload);
        BC.bluetooth.addEventListener("bluetoothstatechange", completed);
        BC.Bluetooth.OpenBluetooth(function() {
          console.log("蓝牙已经打开");
          $scope.scanDevices();
        }, function() {
          console.log("蓝牙打开过程中出错!");
          $scope.scanDevices();
        });
      }
    }
  });
  $scope.$on("$destroy", function() {
    if (window.plugins) {
      if (BC) {
        BC.Bluetooth.StopScan();
      }
    }
  });
}]);
