angular.module("directives", []).directive("lbImageOnload", ["Tools", function(dataAndEvents) {
  return{
    restrict : "A",
    /**
     * @param {string} opt_attributes
     * @param {?} replacementHash
     * @return {undefined}
     */
    link : function(opt_attributes, replacementHash) {
      replacementHash.bind("load", function() {
        /** @type {Element} */
        var img = document.createElement("img");
        img.src = this.src;
        var width = img.width;
        var height = img.height;
        var region = dataAndEvents.getWindowSizes();
        /** @type {number} */
        var w = 0;
        /** @type {number} */
        var h = 0;
        if (width > region[0] || height > region[1]) {
          /** @type {number} */
          var ratio = region[0] / width;
          /** @type {number} */
          var scale = region[1] / height;
          if (scale > ratio) {
            /** @type {number} */
            w = width * ratio;
            /** @type {number} */
            h = height * ratio;
          } else {
            /** @type {number} */
            w = width * scale;
            /** @type {number} */
            h = height * scale;
          }
        } else {
          w = width;
          h = height;
        }
        this.width = w;
        this.height = h;
      });
    }
  };
}]).directive("lbCategoryCollection", function() {
  return{
    restrict : "E",
    replace : true,
    scope : {
      collection : "=",
      goodsCategoryModal : "=",
      goodsInfo : "="
    },
    template : "<lb-category-member ng-repeat='member in collection' member='member' goods-info='goodsInfo' goods-category-modal='goodsCategoryModal'></lb-category-member>"
  };
}).directive("lbCategoryMember", ["$compile", function($resource) {
  return{
    restrict : "E",
    replace : true,
    scope : {
      member : "=",
      goodsCategoryModal : "=",
      goodsInfo : "="
    },
    template : "<div></div>",
    /**
     * @param {string} opt_attributes
     * @param {?} replacementHash
     * @return {undefined}
     */
    link : function(opt_attributes, replacementHash) {
      if (angular.isArray(opt_attributes.member.children)) {
        replacementHash.append(opt_attributes.member.isLeaf ? "<ion-radio ng-model='goodsInfo.category' ng-value='member' ng-click='goodsCategoryModal.hide();'><span class='lb-color-05'>|--</span> {{member.name}}</ion-radio>" : "<ion-radio ng-model='goodsInfo.category' ng-value='member' ng-click='goodsCategoryModal.hide();'>{{member.name}}</ion-radio>");
        replacementHash.append("<lb-category-collection class='pl20 lb-KEY291-categoryList' collection='member.children'></lb-category-collection>");
        $resource(replacementHash.contents())(opt_attributes);
      }
    }
  };
}]).directive("selectOnTap", function() {
  return function(dataAndEvents, el) {
    el.bind("tap", function() {
      this.focus();
      this.select();
    });
  };
}).directive("focusMe", ["$timeout", "Tools", function($transition, dataAndEvents) {
  return{
    scope : {
      trigger : "=focusMe"
    },
    /**
     * @param {string} opt_attributes
     * @param {?} replacementHash
     * @return {undefined}
     */
    link : function(opt_attributes, replacementHash) {
      opt_attributes.$watch("trigger", function(dataAndEvents) {
        if (dataAndEvents === true) {
          $transition(function() {
            replacementHash[0].focus();
            /** @type {boolean} */
            opt_attributes.trigger = false;
            if (ionic.Platform.isAndroid()) {
              dataAndEvents.keyboardShow();
            }
          }, 300);
        }
      });
    }
  };
}]).directive("hideTabs", ["$timeout", "$rootScope", function(deepDataAndEvents, dataAndEvents) {
  return{
    restrict : "A",
    /**
     * @param {string} opt_attributes
     * @return {undefined}
     */
    link : function(opt_attributes) {
      /** @type {boolean} */
      dataAndEvents.hideTabs = false;
      opt_attributes.$on("$destroy", function() {
        /** @type {boolean} */
        dataAndEvents.hideTabs = true;
      });
    }
  };
}]).directive("validPrice", function() {
  return{
    require : "?ngModel",
    /**
     * @param {string} opt_attributes
     * @param {?} replacementHash
     * @param {string} scope
     * @param {Object} ngModel
     * @return {undefined}
     */
    link : function(opt_attributes, replacementHash, scope, ngModel) {
      if (ngModel) {
        ngModel.$parsers.push(function(param) {
          if (angular.isUndefined(param)) {
            /** @type {string} */
            param = "";
          }
          var value = param.replace(/[^0-9\.]/g, "");
          var item = value.split(".");
          return angular.isUndefined(item[1]) || (item[1] = item[1].slice(0, 2), value = item[0] + "." + item[1]), param !== value && (ngModel.$setViewValue(value), ngModel.$render()), value;
        });
        replacementHash.bind("keypress", function(event) {
          if (32 === event.keyCode) {
            event.preventDefault();
          }
        });
      }
    }
  };
}).directive("qrcode", ["$window", function($window) {
  /** @type {boolean} */
  var perm = !!$window.CanvasRenderingContext2D;
  var levels = {
    L : "Low",
    M : "Medium",
    Q : "Quartile",
    H : "High"
  };
  /**
   * @param {CanvasRenderingContext2D} context
   * @param {?} qr
   * @param {number} modules
   * @param {number} tile
   * @return {undefined}
   */
  var draw = function(context, qr, modules, tile) {
    /** @type {number} */
    var row = 0;
    for (;modules > row;row++) {
      /** @type {number} */
      var col = 0;
      for (;modules > col;col++) {
        /** @type {number} */
        var tWidth = Math.ceil((col + 1) * tile) - Math.floor(col * tile);
        /** @type {number} */
        var height = Math.ceil((row + 1) * tile) - Math.floor(row * tile);
        /** @type {string} */
        context.fillStyle = qr.isDark(row, col) ? "#000" : "#fff";
        context.fillRect(Math.round(col * tile), Math.round(row * tile), tWidth, height);
      }
    }
  };
  return{
    restrict : "E",
    template : '<canvas class="qrcode"></canvas>',
    /**
     * @param {string} opt_attributes
     * @param {?} replacementHash
     * @param {Object} attrs
     * @return {undefined}
     */
    link : function(opt_attributes, replacementHash, attrs) {
      var message;
      var version;
      var errorCorrectionLevel;
      var data;
      var size;
      var modules;
      var tile;
      var qr;
      var $img;
      var link = replacementHash[0];
      var t = replacementHash.find("canvas");
      var canvas = t[0];
      var type = perm ? canvas.getContext("2d") : null;
      /** @type {boolean} */
      var text = "download" in attrs;
      var url = attrs.href;
      /** @type {(Element|string)} */
      var $ = text || url ? document.createElement("a") : "";
      /** @type {RegExp} */
      var r20 = /^\s+|\s+$/g;
      /**
       * @param {?} value
       * @return {undefined}
       */
      var setVersion = function(value) {
        /** @type {number} */
        version = Math.max(1, Math.min(parseInt(value, 10), 10)) || 4;
      };
      /**
       * @param {string} value
       * @return {undefined}
       */
      var setErrorCorrectionLevel = function(value) {
        errorCorrectionLevel = value in levels ? value : "M";
      };
      /**
       * @param {string} aValue
       * @return {?}
       */
      var setData = function(aValue) {
        if (aValue) {
          data = aValue.replace(r20, "");
          qr = qrcode(version, errorCorrectionLevel);
          qr.addData(data);
          try {
            qr.make();
          } catch (exception) {
            return void(message = exception.message);
          }
          /** @type {boolean} */
          message = false;
          modules = qr.getModuleCount();
        }
      };
      /**
       * @param {number} width
       * @return {undefined}
       */
      var setSize = function(width) {
        /** @type {number} */
        size = parseInt(width, 10) || 2 * modules;
        /** @type {number} */
        tile = size / modules;
        /** @type {number} */
        canvas.width = canvas.height = size;
      };
      /**
       * @return {?}
       */
      var update = function() {
        if (qr) {
          if (message) {
            return $ && ($.removeAttribute("download"), $.title = "", $.href = "#_"), perm || (link.innerHTML = '<img src width="' + size + '"height="' + size + '"class="qrcode">'), void opt_attributes.$emit("qrcode:error", message);
          }
          if (text && (link.download = "qrcode.png", link.title = "Download QR code"), perm) {
            if (draw(type, qr, modules, tile), text) {
              return void(link.href = canvas.toDataURL("image/png"));
            }
          } else {
            if (link.innerHTML = qr.createImgTag(tile, 0), $img = replacementHash.find("img"), $img.addClass("qrcode"), text) {
              return void(link.href = $img[0].src);
            }
          }
          if (url) {
            link.href = url;
          }
        }
      };
      if ($) {
        /** @type {string} */
        $.className = "qrcode-link";
        t.wrap($);
        link = link.firstChild;
      }
      setVersion(attrs.version);
      setErrorCorrectionLevel(attrs.errorCorrectionLevel);
      setSize(attrs.size);
      attrs.$observe("version", function(isXML) {
        if (isXML) {
          setVersion(isXML);
          setData(data);
          setSize(size);
          update();
        }
      });
      attrs.$observe("errorCorrectionLevel", function(isXML) {
        if (isXML) {
          setErrorCorrectionLevel(isXML);
          setData(data);
          setSize(size);
          update();
        }
      });
      attrs.$observe("data", function(value) {
        if (value) {
          setData(value);
          setSize(size);
          update();
        }
      });
      attrs.$observe("size", function(width) {
        if (width) {
          setSize(width);
          update();
        }
      });
      attrs.$observe("href", function(parameter) {
        if (parameter) {
          /** @type {string} */
          url = parameter;
          update();
        }
      });
    }
  };
}]);
