angular.module("services", ["tools"]).factory("lruPersistCache", ["$cacheFactory", function($sanitize) {
  return $sanitize("lruPersistCache");
}]).factory("psisServices", ["$http", "Tools", "ServerConfig", "$state", "$window", "$ionicPopup", "$cacheFactory", "HttpActionConstant", "lbSpinnerDialog", function(db, self, context, $state, model, dataAndEvents, $cacheFactory, ac, poster) {
  var cache = $cacheFactory("lruCache", {
    capacity : 20
  });
  /**
   * @param {Function} response
   * @param {number} allBindingsAccessor
   * @return {undefined}
   */
  var init = function(response, allBindingsAccessor) {
    if (500 === allBindingsAccessor) {
      self.toastShow(response && response.statusCode ? response.content : "服务器获取数据出现异常！");
    } else {
      if (403 === allBindingsAccessor) {
        if (response && response.statusCode) {
          if (1403 === response.statusCode) {
            poster.hide();
            self.showAlert(response.content, function() {
              if (!$state.includes("signin")) {
                /** @type {string} */
                model.localStorage.password = "";
                $state.go("signin");
              }
            });
          } else {
            self.toastShow(response.content);
          }
        } else {
          self.toastShow("服务器获取数据出现异常！");
        }
      } else {
        self.toastShow(context.currentServer.indexOf("dev") > -1 ? "当前网络不可用！状态码：" + allBindingsAccessor + "-----" + response : "当前网络不可用！(" + allBindingsAccessor + ")");
        cache.removeAll();
        poster.hide();
      }
    }
    console.error("状态码：" + allBindingsAccessor + "-----" + response);
  };
  /**
   * @param {string} obj
   * @param {?} opt_attributes
   * @param {?} callback
   * @return {?}
   */
  var save = function(obj, opt_attributes, callback) {
    return db.post(context.currentServer + obj, opt_attributes, callback).error(init);
  };
  /**
   * @param {string} req
   * @param {?} data
   * @param {?} callback
   * @return {?}
   */
  var authenticate = function(req, data, callback) {
    return db.post(req, data, callback).error(init);
  };
  return{
    httpCacheGet : {
      lruCache : cache,
      ac : ac,
      /**
       * @param {?} keepData
       * @return {undefined}
       */
      remove : function(keepData) {
        cache.remove(context.currentServer + keepData);
      },
      /**
       * @param {string} sid
       * @param {?} obj
       * @return {?}
       */
      get : function(sid, obj) {
        var options = {
          cache : cache
        };
        return obj && angular.extend(options, obj), db.get(context.currentServer + sid, options).error(init);
      },
      /**
       * @param {number} i
       * @param {number} sid
       * @param {(Node|string)} data
       * @return {?}
       */
      getByServer : function(i, sid, data) {
        var options = {
          cache : cache
        };
        return data && angular.extend(options, data), db.get(i + sid, options).error(init);
      }
    },
    /**
     * @param {string} sid
     * @param {?} options
     * @return {?}
     */
    get : function(sid, options) {
      return db.get(context.currentServer + sid, options).error(init);
    },
    /** @type {function (string, ?, ?): ?} */
    post : save,
    /**
     * @param {string} walkers
     * @param {?} opt_attributes
     * @return {?}
     */
    postArrParamEncode : function(walkers, opt_attributes) {
      return save(walkers, self.getArrayParam(opt_attributes), {
        headers : {
          "Content-Type" : "application/x-www-form-urlencoded; charset=UTF-8"
        }
      });
    },
    /**
     * @param {string} obj
     * @param {?} opt_attributes
     * @return {?}
     */
    postEncode : function(obj, opt_attributes) {
      return save(obj, $.param(opt_attributes), {
        headers : {
          "Content-Type" : "application/x-www-form-urlencoded; charset=UTF-8"
        }
      });
    },
    /**
     * @param {string} regex
     * @param {string} attributes
     * @return {?}
     */
    fullPathPostEncode : function(regex, attributes) {
      return authenticate(regex, $.param(attributes), {
        headers : {
          "Content-Type" : "application/x-www-form-urlencoded; charset=UTF-8"
        }
      });
    }
  };
}]).constant("HttpActionConstant", {
  COLORGROUP : "/KEY064",
  COLORSELECT : "/KEY065",
  SIZEGROUP : "/KEY066",
  SIZESELECT : "/KEY067",
  BLANDLIST : "/KEY059",
  CATEGORYLIST : "/KEY052",
  UNITLIST : "/KEY068",
  KEY177 : "/KEY070",
  ALLSIZELIST : "/KEY094",
  ALLCOLORLIST : "/KEY095",
  ALLACCOUNT : "/KEY002",
  ALLACCOUNTITEM : "/KEY012",
  ALLDELIVERY : "/KEY049",
  ALLONLINEDELIVERY : "/KEY338",
  ALLCOMPANYUSER : "/KEY247?queryAll=true",
  ALLCLIENTITEMS : "/KEY069",
  ALLSUPPLIERTYPES : "/KEY476",
  AllArea : "/KEY031",
  LogisticsCompany : "/KEY044",
  STOREHOUSELISTBYCOMSTORE : "/KEY070?filterComStore=1",
  ALLACCOUNTBYCOMSTORE : "/KEY002?filterComStore=1",
  STOREHOUSECHECKCONFIG : "/KEY183?filterComStore=1",
  COMPANYUSERBYCOMSTORE : "/KEY258?queryAll=true",
  COMPANYUSERBYPARAM : "/KEY258?queryAll=true&isSearchParam=1",
  RESOURCEHIERARCHY : "/KEY367",
  ALLECOMMERCEDELIVERY : "/KEY404",
  STOREHOUSEAVAILABLE : "/KEY070?showDisable=1",
  SEASONLIST : "/KEY390",
  MATERIALLIST : "/KEY368",
  STYLELIST : "/KEY403",
  COMPANYUSERBYCASHIER : "/KEY258?queryAll=true&status=1",
  TMSGOODSDELIVERYFEELIST : "/KEY302",
  SIGNINCOMPANYLIST : "/sign-out/client",
  SIGNINCOUNT : "/sign-out/count",
  SIGNINPERSONLIST : "/sign-out/person"
}).factory("qqShare", ["psisServices", "Tools", "lbSpinnerDialog", "OrderType", "$filter", function() {
  /**
   * @param {?} form
   * @param {string} title
   * @param {boolean} src
   * @param {string} data
   * @param {string} textStatus
   * @return {undefined}
   */
  var error = function(form, title, src, data, textStatus) {
    var o = {
      url : form,
      title : title ? title : "",
      description : src ? src : "暂无描述",
      imageUrl : data ? data : "http://app.xinbafar.com.cn:8080/business/m/img/share/logoShare.png",
      appName : textStatus ? textStatus : "辛巴手机版"
    };
    YCQQ.shareToQQ(function() {
      console.log("qq分享成功");
    }, function() {
      console.log("qq分享失败");
    }, o);
  };
  /**
   * @param {?} form
   * @param {string} title
   * @param {boolean} src
   * @param {Object} values
   * @return {undefined}
   */
  var save = function(form, title, src, values) {
    var o = {
      url : form,
      title : title ? title : "",
      description : src ? src : "暂无描述",
      imageUrl : values ? values : ["http://app.xinbafar.com.cn:8080/business/m/img/share/logoShare.png"]
    };
    YCQQ.shareToQzone(function() {
      console.log("qq空间分享成功");
    }, function() {
      console.log("qq空间分享失败");
    }, o);
  };
  return{
    /** @type {function (?, string, boolean, string, string): undefined} */
    shareUrlToQq : error,
    /** @type {function (?, string, boolean, Object): undefined} */
    shareUrlToQz : save
  };
}]).factory("wechatShare", ["psisServices", "Tools", "lbSpinnerDialog", "OrderType", "$filter", function($http, spec, loading) {
  /**
   * @param {?} __
   * @param {?} label
   * @param {(Element|string)} text
   * @param {string} input
   * @param {string} buffer
   * @return {undefined}
   */
  var callback = function(__, label, text, input, buffer) {
    Wechat.share({
      message : {
        title : text,
        description : input ? input : "",
        thumb : buffer ? buffer : "http://app.xinbafar.com.cn:8080/business/m/img/share/logoShare.png",
        media : {
          type : Wechat.Type.WEBPAGE,
          webpageUrl : label
        }
      },
      scene : __
    }, function() {
      console.log("分享成功！");
    }, function(reply) {
      console.log("分享失败！" + reply);
    });
  };
  /**
   * @param {?} obj
   * @param {?} title
   * @param {?} ast
   * @param {string} data
   * @return {undefined}
   */
  var init = function(obj, title, ast, data) {
    callback(Wechat.Scene.SESSION, obj, title, ast, data);
  };
  /**
   * @param {?} obj
   * @param {?} title
   * @param {?} ast
   * @param {string} data
   * @return {undefined}
   */
  var log = function(obj, title, ast, data) {
    callback(Wechat.Scene.TIMELINE, obj, title, ast, data);
  };
  /**
   * @param {?} element
   * @param {?} value
   * @return {undefined}
   */
  var save = function(element, value) {
    loading.show();
    $http.post("/admin/share/getDocumentationUrl.ac?sn=" + element + "&type=" + value).success(function(response) {
      if (1 === response.statusCode) {
        init(response.object.shareLink, response.object.shareTitle, response.object.description, response.object.shareImg);
      } else {
        spec.toastShow("分享失败！");
      }
    }).finally(function() {
      loading.hide();
    });
  };
  /**
   * @param {?} func
   * @param {number} isXML
   * @param {?} opt_async
   * @return {undefined}
   */
  var open = function(func, isXML, opt_async) {
    loading.show();
    $http.post("/KEY337", {
      createTimeBegin : spec.getDayBegin(func),
      createTimeEnd : spec.getOffsetDayBegin(isXML, 1),
      oppositeSideId : opt_async
    }).success(function(response) {
      if (1 === response.statusCode) {
        init(response.object.shareLink, response.object.shareTitle, response.object.description, response.object.shareImg);
      } else {
        spec.toastShow("分享失败！");
      }
    }).finally(function() {
      loading.hide();
    });
  };
  /**
   * @param {string} service
   * @param {?} data
   * @param {?} stat
   * @param {string} callback
   * @param {number} opt_noCache
   * @return {undefined}
   */
  var send = function(service, data, stat, callback, opt_noCache) {
    loading.show();
    $http.post(service).success(function(message) {
      if (1 === message.statusCode) {
        if (2 === opt_noCache) {
          log(message.backUrl, data, stat, callback);
        } else {
          init(message.backUrl, data, stat, callback);
        }
      } else {
        spec.toastShow("分享失败！");
      }
    }).finally(function() {
      loading.hide();
    });
  };
  return{
    /** @type {function (?, ?, ?, string): undefined} */
    shareUrlToSession : init,
    /** @type {function (?, ?): undefined} */
    shareSnUrl : save,
    /** @type {function (?, number, ?): undefined} */
    shareClientDebtUrl : open,
    /** @type {function (string, ?, ?, string, number): undefined} */
    shareCommonUrl : send,
    /** @type {function (?, ?, ?, string): undefined} */
    shareUrlToTimeline : log
  };
}]).factory("lbScrollDelegate", ["$ionicScrollDelegate", function(Ext) {
  return{
    /**
     * @param {string} value
     * @return {undefined}
     */
    scrollTop : function(value) {
      if (Ext.$getByHandle(value)) {
        Ext.$getByHandle(value).scrollTop();
      }
    },
    /**
     * @param {string} easing
     * @return {undefined}
     */
    scrollBottom : function(easing) {
      if (Ext.$getByHandle(easing)) {
        Ext.$getByHandle(easing).scrollBottom();
      }
    },
    /**
     * @param {string} event
     * @return {undefined}
     */
    resize : function(event) {
      if (Ext.$getByHandle(event)) {
        Ext.$getByHandle(event).resize();
      }
    },
    /**
     * @param {string} centerX
     * @param {number} deepDataAndEvents
     * @param {boolean} recurring
     * @param {number} crossScope
     * @param {number} lab
     * @return {undefined}
     */
    zoomTo : function(centerX, deepDataAndEvents, recurring, crossScope, lab) {
      if (Ext.$getByHandle(centerX)) {
        Ext.$getByHandle(centerX).zoomTo(deepDataAndEvents, recurring, crossScope, lab);
      }
    },
    /**
     * @param {number} y
     * @param {number} recurring
     * @param {boolean} deepDataAndEvents
     * @return {undefined}
     */
    scrollTo : function(y, recurring, deepDataAndEvents) {
      if (Ext.$getByHandle(y)) {
        Ext.$getByHandle(y).scrollTo(recurring, deepDataAndEvents);
      }
    },
    /**
     * @param {?} easing
     * @return {undefined}
     */
    triggerPullToRefresh : function(easing) {
      if (Ext.$getByHandle(easing)) {
        Ext.$getByHandle(easing).getScrollView().triggerPullToRefresh();
      }
    }
  };
}]).factory("lbSpinnerDialog", ["$cordovaSpinnerDialog", "$window", "$ionicLoading", "$timeout", function(loading, proto, thingy, $timeout) {
  return{
    /**
     * @param {boolean} expectedNumberOfNonCommentArgs
     * @return {undefined}
     */
    show : function(expectedNumberOfNonCommentArgs) {
      if (proto.plugins && proto.plugins.spinnerDialog) {
        loading.show(null, null, expectedNumberOfNonCommentArgs);
      } else {
        thingy.show();
      }
    },
    /**
     * @return {undefined}
     */
    hide : function() {
      if (proto.plugins && proto.plugins.spinnerDialog) {
        $timeout(function() {
          loading.hide();
        }, 150);
      } else {
        thingy.hide();
      }
    }
  };
}]).service("CameraService", ["$q", "$cordovaCamera", function(dataAndEvents, item) {
  return{
    /**
     * @param {boolean} dataAndEvents
     * @return {?}
     */
    startCamera : function(dataAndEvents) {
      return item.getPicture({
        quality : dataAndEvents ? 100 : 75,
        allowEdit : dataAndEvents,
        destinationType : Camera.DestinationType.FILE_URI,
        sourceType : Camera.PictureSourceType.CAMERA,
        targetWidth : 800,
        targetHeight : 800
      });
    },
    /**
     * @param {boolean} dataAndEvents
     * @return {?}
     */
    openCameraRoll : function(dataAndEvents) {
      return item.getPicture({
        quality : dataAndEvents ? 100 : 75,
        allowEdit : dataAndEvents,
        destinationType : Camera.DestinationType.FILE_URI,
        sourceType : Camera.PictureSourceType.PHOTOLIBRARY,
        targetWidth : 800,
        targetHeight : 800
      });
    },
    /**
     * @return {?}
     */
    cleanup : function() {
      return item.cleanup();
    }
  };
}]).service("BluetoothPrintService", ["Tools", "OrderType", "$state", "lruPersistCache", "$ionicPopup", "$filter", "ServerConfig", "psisServices", "$q", "$window", "$ionicHistory", "lbSpinnerDialog", "PrintType", function(self, ide, req, elem, view, join, collection, db, $q, JSpec, $history, loading, dataAndEvents) {
  /**
   * @param {string} key
   * @param {string} callback
   * @param {string} arg
   * @return {?}
   */
  function next(key, callback, arg) {
    var result;
    switch(arg) {
      case ide.retailOrder:
        result = exec(key, callback, ide.retailOrder);
        break;
      case ide.saleOrder:
        result = save(key, callback, ide.saleOrder);
        break;
      case ide.saleReturnOrder:
        result = save(key, callback, ide.saleReturnOrder);
        break;
      case ide.KEY329:
        result = compile(key, callback, ide.KEY329);
        break;
      case ide.KEY330:
        result = compile(key, callback, ide.KEY330);
        break;
      case ide.transferOrder:
        result = get(key, callback, ide.transferOrder);
        break;
      case ide.receiptOrder:
        result = request(key, callback, ide.receiptOrder);
        break;
      case ide.fastReceiptOrder:
        result = load(key, callback, ide.fastReceiptOrder);
        break;
      case ide.logisticsOrder:
        result = read(key, callback, ide.logisticsOrder);
        break;
      case ide.eorder:
        result = process(key, callback, ide.eorder);
        break;
      case ide.ehsopLogisticsOrder:
        result = parse(key, callback, ide.ehsopLogisticsOrder);
        break;
      default:
        result = void 0;
    }
    return result;
  }


  function runTestPrint(config, elem, name, path, dataAndEvents) {
    loading.show();
    window.plugins.bluetoothPrinter.print(function(speed) {
      if (speed) {
        self.toastShow(speed);
      }
      if (dataAndEvents) {
        $history.goBack();
      }
      if ("string" == typeof name) {
        if (name && (name.indexOf("PF") > -1 || name.indexOf("TH") > -1)) {
          db.post("/KEY470?orderSn=" + name).success(function() {
            elem.put("saleListRefresh", true);
          });
        } else {
          if (name) {
            if (name.indexOf("DB") > -1) {
              db.post("/KEY471?orderSn=" + name).success(function() {
                elem.put("storeTransferListRefresh", true);
              });
            }
          }
        }
      }
    }, function(speed) {
      if (speed) {
        self.toastShow(speed);
      }
    }, newUrl, JSpec.localStorage["PrintTimes" + path]);
  }

  /**
   * @param {string} config
   * @param {string} elem
   * @param {string} name
   * @param {string} path
   * @param {boolean} dataAndEvents
   * @return {undefined}
   */
  function run(config, elem, name, path, dataAndEvents) {
    loading.show();
    window.plugins.bluetoothPrinter.open(function() {
      var win = next(elem, name, path);
      if (win) {
        win.then(function(newUrl) {
          /** @type {number} */
          JSpec.localStorage.isBLEPrinted = 1;
          if (void 0 != newUrl && (null != newUrl && "" != newUrl)) {
            window.plugins.bluetoothPrinter.print(function(speed) {
              if (speed) {
                self.toastShow(speed);
              }
              if (dataAndEvents) {
                $history.goBack();
              }
              if ("string" == typeof name) {
                if (name && (name.indexOf("PF") > -1 || name.indexOf("TH") > -1)) {
                  db.post("/KEY470?orderSn=" + name).success(function() {
                    elem.put("saleListRefresh", true);
                  });
                } else {
                  if (name) {
                    if (name.indexOf("DB") > -1) {
                      db.post("/KEY471?orderSn=" + name).success(function() {
                        elem.put("storeTransferListRefresh", true);
                      });
                    }
                  }
                }
              }
            }, function(speed) {
              if (speed) {
                self.toastShow(speed);
              }
            }, newUrl, JSpec.localStorage["PrintTimes" + path]);
            if (void 0 == JSpec.localStorage["bluePrinter" + path] || JSpec.localStorage["bluePrinter" + path] != config) {
              /** @type {string} */
              JSpec.localStorage["bluePrinter" + path] = config;
            }
          } else {
            self.toastShow("无打印数据");
          }
          loading.hide();
        }, function() {
          loading.hide();
          self.toastShow("获取打印数据异常！");
        });
      } else {
        loading.hide();
      }
    }, function() {
      loading.hide();
      view.alert({
        title : "设备连接失败",
        template : "1.若打印设备被占用，请稍候再试<br>2.若打印设备未占用，请重启打印设备",
        okText : "确定"
      }).then(function() {
        if (!req.is("eventmenu.KEY116")) {
          log(name, path);
        }
      });
    }, config);
  }
  /**
   * @param {string} callback
   * @param {string} name
   * @param {string} config
   * @param {string} path
   * @param {boolean} dataAndEvents
   * @return {undefined}
   */
  function initialize(callback, name, config, path, dataAndEvents) {
    window.plugins.bluetoothPrinter.open(function() {
      var result = next(name, config, path);
      if (result) {
        result.then(function(val) {
          /** @type {number} */
          JSpec.localStorage.isBLEPrinted = 1;
          if (void 0 != val) {
            if (null != val) {
              if ("" != val) {
                window.plugins.bluetoothPrinter.printExpressArray(function(speed) {
                  if (speed) {
                    self.toastShow(speed);
                    if (path == ide.ehsopLogisticsOrder) {
                      elem.put("eshopOrderStatus", true);
                    }
                  }
                  if (dataAndEvents) {
                    $history.goBack();
                  }
                }, function(speed) {
                  if (speed) {
                    self.toastShow(speed);
                  }
                }, val, JSpec.localStorage["PrintTimes" + path]);
                if (void 0 == JSpec.localStorage["bluePrinter" + path] || JSpec.localStorage["bluePrinter" + path] != callback) {
                  /** @type {string} */
                  JSpec.localStorage["bluePrinter" + path] = callback;
                }
              }
            }
          }
        }, function() {
          self.toastShow("服务器获取数据出现异常！");
        });
      }
    }, function() {
      view.alert({
        title : "设备连接失败",
        template : "1.若打印设备被占用，请稍候再试<br>2.若打印设备未占用，请重启打印设备",
        okText : "确定"
      });
    }, callback);
  }
  /**
   * @param {?} config
   * @param {?} callback
   * @param {Array} args
   * @param {?} curVal
   * @param {(Object|string)} allBindingsAccessor
   * @param {boolean} dataAndEvents
   * @return {undefined}
   */
  function init(config, callback, args, curVal, allBindingsAccessor, dataAndEvents) {
    loading.show();
    window.plugins.bluetoothPrinter.open(function() {
      if (args.length > 0) {
        /** @type {number} */
        JSpec.localStorage.isBLEPrinted = 1;
        if (allBindingsAccessor == dataAndEvents.printLabel) {
          window.plugins.bluetoothPrinter.printLabelArray(function(speed) {
            if (speed) {
              self.toastShow(speed);
            }
            if (dataAndEvents) {
              $history.goBack();
            }
          }, function(speed) {
            if (speed) {
              self.toastShow(speed);
            }
          }, callback, args, curVal.toString());
          if (void 0 == JSpec.localStorage.bluePrinterBarCodeId || JSpec.localStorage.bluePrinterBarCodeId != config) {
            JSpec.localStorage.bluePrinterBarCodeId = config;
          }
        } else {
          if (allBindingsAccessor == dataAndEvents.printQRCode) {
            window.plugins.bluetoothPrinter.printTMSQRcodeArray(function(speed) {
              if (speed) {
                self.toastShow(speed);
              }
              if (dataAndEvents) {
                $history.goBack();
              }
            }, function(speed) {
              if (speed) {
                self.toastShow(speed);
              }
            }, callback, args, curVal.toString());
          }
        }
      } else {
        self.toastShow("无打印数据");
      }
      loading.hide();
    }, function() {
      loading.hide();
      view.alert({
        title : "设备连接失败",
        template : "1.若打印设备被占用，请稍候再试<br>2.若打印设备未占用，请重启打印设备",
        okText : "确定"
      });
    }, config);
  }
  /**
   * @param {?} text
   * @param {?} name
   * @return {undefined}
   */
  function log(text, name) {
    elem.put("bluePrintType", name);
    elem.put("bluePrintSN", text);
    req.go("eventmenu.KEY116");
  }
  /**
   * @param {?} deepDataAndEvents
   * @param {?} text
   * @param {string} fileName
   * @return {undefined}
   */
  function write(deepDataAndEvents, text, fileName) {
    var c = JSpec.localStorage["bluePrinter" + fileName];
    //胜天,判断是否有蓝牙打印机，无打印机调试，可修改这里
    //runTestPrint(c, deepDataAndEvents, text, fileName);
    if (void 0 != c && "" != c) {
      run(c, deepDataAndEvents, text, fileName);
    } else {
      self.toastShow("请选择您的蓝牙打印机");
      log(text, fileName);
    }
  }
  /**
   * @param {?} deepDataAndEvents
   * @param {?} t
   * @param {?} path
   * @return {undefined}
   */
  function done(deepDataAndEvents, t, path) {
    /** @type {boolean} */
    var o = void 0 !== JSpec.localStorage["QSAutoPrinted" + path] ? "true" == JSpec.localStorage["QSAutoPrinted" + path] : false;
    if (o) {
      write(deepDataAndEvents, t, path);
    }
  }
  /**
   * @param {?} e
   * @param {string} key
   * @param {string} right
   * @param {Object} value
   * @return {?}
   */
  function fn(e, key, right, value) {
    value = value ? value : "";
    /** @type {string} */
    var colStr = "";
    if ("center" == right) {
      /** @type {number} */
      var best_s = 0;
      /** @type {number} */
      var s = (e - self.getBytesLength(key + value)) / 2;
      for (;s > best_s;best_s++) {
        colStr += " ";
      }
    } else {
      if ("right" == right) {
        /** @type {number} */
        best_s = 0;
        /** @type {number} */
        s = e - self.getBytesLength(key + value);
        for (;s > best_s;best_s++) {
          colStr += " ";
        }
      }
    }
    return colStr += key;
  }
  /**
   * @param {number} n
   * @param {string} name
   * @param {string} value
   * @return {?}
   */
  function $(n, name, value) {
    var val = fn(n, name, value);
    return val += "\n";
  }
  /**
   * @param {number} a
   * @return {?}
   */
  function cb(a) {
    /** @type {string} */
    var uuid = "";
    /** @type {number} */
    var b = 0;
    for (;a > b;b++) {
      uuid += "-";
    }
    return uuid += "\n";
  }
  /**
   * @param {number} key
   * @param {number} dataAndEvents
   * @param {Object} timeOutMillis
   * @return {?}
   */
  function clone(key, dataAndEvents, timeOutMillis) {
    /** @type {number} */
    var ms = key - dataAndEvents;
    /** @type {number} */
    ms = ms % 1 == 0 ? ms : ms - 1;
    /** @type {string} */
    var res = "";
    var maxtimeOutMillis = timeOutMillis ? timeOutMillis : " ";
    if (ms > 0) {
      /** @type {number} */
      var s = 0;
      for (;ms > s;s++) {
        res += maxtimeOutMillis;
      }
    }
    return res;
  }
  /**
   * @param {number} key
   * @param {number} dataAndEvents
   * @param {?} state
   * @return {?}
   */
  function callback(key, dataAndEvents, state) {
    var c = clone(key, dataAndEvents);
    return state.goodsDetail += c, c;
  }
  /**
   * @param {Object} scope
   * @param {number} r
   * @param {boolean} view
   * @param {string} ctx
   * @param {Array} container
   * @param {boolean} boardState
   * @param {number} setting
   * @return {?}
   */
  function render(scope, r, view, ctx, container, boardState, setting) {
    /**
     * @param {Array} rows
     * @return {undefined}
     */
    function render(rows) {
      rows.forEach(function(item) {
        /** @type {string} */
        var data = "";
        if (str = "", A++, opt_nmTokenPolicy ? 1 == item.type ? (str += "[销]", count += item.quantity, amount = self.accAdd(amount, self.accMul(item.truePrice, item.quantity)), previous = self.accAdd(previous, self.accMul(self.accSub(item.price, item.truePrice), item.quantity))) : 2 == item.type && (str += "[退]", sum +=
        item.quantity, interval = self.accAdd(interval, self.accMul(item.truePrice, item.quantity)), now = self.accAdd(now, self.accMul(self.accSub(item.price, item.truePrice), item.quantity))) : value = self.accAdd(value, self.accMul(self.accSub(item.price, item.truePrice), item.quantity)), (!view || ctx.indexOf("goodsSn") >
        -1) && (str += self.trim(item.goodsSn, true) + "/"), str += item.goodName, (!view || ctx.indexOf("color") > -1) && (str += "  " + item.colorName), (!view || ctx.indexOf("size") > -1) && (str += "  " + item.sizeName), !isVisible) {
          var chunk = item.price.toFixed(2)
        }
        var body = item.quantity.toString() + (item.unit ? item.unit : " ");
        var d = item.truePrice.toFixed(2);
        var v = isVisible ? item.amount.toFixed(2) : item.trueAmount.toFixed(2);
        if (!isVisible) {
          var activationScript = item.discount.toString()
        }
        res.goodsDetail += str;
        data += str;
        if (!(self.getBytesLength(container[1].currentSpace) - self.getBytesLength(str) >= 0)) {
          res.goodsDetail += "\n";
          /** @type {string} */
          data = "";
        }
        /** @type {number} */
        var nodeType = 1;
        var c = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(data));
        if (nodeType++, res.goodsDetail += c, data += c, ctx && ctx.indexOf("orig") > -1) {
          res.goodsDetail += chunk;
          data += chunk;
          c = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(data));
          nodeType++;
          res.goodsDetail += c;
          data += c;
        }
        res.goodsDetail += body;
        data += body;
        c = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(data));
        if (nodeType++, res.goodsDetail += c, data += c, ctx && ctx.indexOf("discount") > -1) {
          res.goodsDetail += activationScript;
          data += activationScript;
          c = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(data));
          nodeType++;
          res.goodsDetail += c;
          data += c;
        }
        res.goodsDetail += d;
        data += d;
        c = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(data));
        nodeType++;
        res.goodsDetail += c;
        data += c;
        res.goodsDetail += v;
        data += v;
        res.goodsDetail += boardState ? "\n" : "\n";
        path += item.quantity;
        if (!boardState) {
          if (A % 3 == 0) {
            res.goodsDetail += cb(r);
          }
        }
      });
    }
    var res = {
      goodsDetail : "",
      total : ""
    };
    /** @type {boolean} */
    var isVisible = 5 == setting;
    /** @type {boolean} */
    var opt_nmTokenPolicy = 2 == setting;
    /** @type {number} */
    var g = 0;
    container.forEach(function(key) {
      if ("折扣%" != key.name || "折扣%" == key.name && (ctx && ctx.indexOf("discount") > -1)) {
        g += self.getBytesLength(key.name);
      } else {
        var child = container.indexOf(key);
        container.splice(child, 1);
      }
    });
    container.forEach(function(details) {
      /** @type {number} */
      var t = 0;
      for (;t < (r - g) * details.sizeToSplit;t++) {
        res.goodsDetail += " ";
      }
      /** @type {string} */
      details.currentSpace = res.goodsDetail;
      res.goodsDetail += details.name;
    });
    res.goodsDetail += "\n";
    /** @type {number} */
    var path = 0;
    /** @type {number} */
    var count = 0;
    /** @type {number} */
    var amount = 0;
    /** @type {number} */
    var sum = 0;
    /** @type {number} */
    var interval = 0;
    /** @type {number} */
    var previous = 0;
    /** @type {number} */
    var now = 0;
    /** @type {string} */
    var str = "";
    /** @type {number} */
    var value = 0;
    /** @type {number} */
    var A = 0;
    /** @type {Array} */
    var namespace = [];
    /** @type {Array} */
    var result = [];
    if (opt_nmTokenPolicy) {
      scope.orderGoods.forEach(function(handler) {
        if (1 == handler.type) {
          namespace.push(handler);
        } else {
          if (2 == handler.type) {
            result.push(handler);
          }
        }
      });
    } else {
      namespace = scope.orderGoods;
    }
    render(namespace);
    if (namespace.length > 0) {
      if (result.length > 0) {
        res.goodsDetail += "\n";
        res.goodsDetail += "销售：" + count + "  " + join("lbCurrency")(amount.toFixed(2), collection.currencySymbol) + "\n";
        res.goodsDetail += cb(r);
      }
    }
    render(result);
    if (namespace.length > 0) {
      if (result.length > 0) {
        res.goodsDetail += "\n";
        res.goodsDetail += "退货：" + sum + "  " + join("lbCurrency")(interval.toFixed(2), collection.currencySymbol) + "\n";
        res.goodsDetail += cb(r);
      }
    }
    if (0 == namespace.length || 0 == result.length) {
      if (boardState) {
        res.goodsDetail += cb(r);
      } else {
        if (A % 3 != 0) {
          res.goodsDetail += cb(r);
        }
      }
    }
    var append = "合计  数量：" + path;
    if (r >= 40) {
      /** @type {number} */
      var b = 0;
      /** @type {number} */
      var a = r / 2 - self.getBytesLength(append);
      for (;a > b;b++) {
        append += " ";
      }
    } else {
      /** @type {string} */
      append = "数量：" + path + "  ";
    }
    if (append += "金额：", isVisible) {
      append += join("lbCurrency")(scope.order.totalAmount.toFixed(2), collection.currencySymbol);
    } else {
      if (setting == ide.saleOrder || setting == ide.KEY329) {
        var arg = scope.order.trueTotalAmount;
        append += join("lbCurrency")(Math.abs(arg).toFixed(2), collection.currencySymbol);
        if (scope.order.wipeZero) {
          arg = self.accSub(arg, scope.order.wipeZero);
        }
        if (scope.order.otherCost) {
          arg = self.accAdd(arg, scope.order.otherCost);
        }
        if (scope.order.wipeZero || scope.order.otherCost) {
          res.goodsDetail += append + "\n";
          res.goodsDetail += cb(r);
          /** @type {string} */
          append = "";
          append += "总金额  ：" + join("lbCurrency")(Math.abs(arg).toFixed(2), collection.currencySymbol);
        }
      } else {
        append += join("lbCurrency")(Math.abs(scope.order.trueTotalAmount).toFixed(2), collection.currencySymbol);
      }
      if (!isVisible) {
        if (ctx) {
          if (ctx.indexOf("discountAmount") > -1) {
            value = opt_nmTokenPolicy ? now - previous : value;
            append += "\n优惠金额：" + join("lbCurrency")(Math.abs(value).toFixed(2), collection.currencySymbol);
          }
        }
      }
    }
    return res.total += append + "\n", res;
  }
  /**
   * @param {Object} scope
   * @param {number} e
   * @param {boolean} view
   * @param {string} label
   * @param {Array} container
   * @param {Object} boardState
   * @param {number} setting
   * @param {Object} from
   * @return {?}
   */
  function start(scope, e, view, label, container, boardState, setting, from) {
    var status = {
      goodsDetail : "",
      total : ""
    };
    from = from ? from : " ";
    /** @type {boolean} */
    var g = 5 == setting ? true : false;
    /** @type {boolean} */
    var r = 2 == setting ? true : false;
    /** @type {number} */
    var s = 0;
    container.forEach(function(key) {
      if ("折扣%" != key.name || "折扣%" == key.name && (label && label.indexOf("discount") > -1)) {
        s += self.getBytesLength(key.name);
      } else {
        var child = container.indexOf(key);
        container.splice(child, 1);
      }
    });
    container.forEach(function($scope) {
      /** @type {number} */
      var t = 0;
      for (;t < (e - s) * $scope.sizeToSplit;t++) {
        status.goodsDetail += " ";
      }
      /** @type {string} */
      $scope.currentSpace = status.goodsDetail;
      status.goodsDetail += $scope.name;
    });
    status.goodsDetail += "\n";
    /** @type {Array} */
    var reporters = [];
    scope.orderGoods.forEach(function(v) {
      /** @type {boolean} */
      var r = false;
      /** @type {number} */
      var klassName = 0;
      /** @type {number} */
      var cnl = reporters.length;
      for (;cnl > klassName;klassName++) {
        var varname = reporters[klassName].goodsSn;
        if (v.goodsSn == varname) {
          /** @type {boolean} */
          r = true;
          reporters[klassName].goods.push(self.getPropertyObj(v, ["colorId", "sizeId", "colorName", "sizeName", "quantity", "price", "discount", "unit", "truePrice", "type"]));
        }
      }
      if (!r) {
        var reporter = {};
        /** @type {Array} */
        reporter.goods = [];
        reporter.goods.push(self.getPropertyObj(v, ["colorId", "sizeId", "colorName", "sizeName", "quantity", "price", "discount", "unit", "truePrice", "type"]));
        reporter.goodName = v.goodName;//全名
        reporter.goodsSn = v.goodsSn;//编号
        reporter.barCode = v.barCode;//条码
        reporters.push(reporter);
      }
    });
    /** @type {number} */
    var count = 0;
    /** @type {number} */
    var v = 0;
    /** @type {number} */
    var sum = 0;
    /** @type {number} */
    var amount = 0;
    /** @type {number} */
    var path = 0;
    /** @type {number} */
    var interval = 0;
    /** @type {number} */
    var previous = 0;
    /** @type {number} */
    var now = 0;
    if (reporters.forEach(function(node) {
      /** @type {string} */
      var text = "";
      //是否显示商品编号
      if (!view || label.indexOf("goodsSn") > -1) {
        text += self.trim(node.goodsSn, true) + "/";
      }
      text += node.goodName;
      //是否显示商品条码
      if (!view || label.indexOf("barCode") > -1) {
        text += "/"+self.trim(node.barCode, true);
      }
      status.goodsDetail += text;
      status.goodsDetail += "\n";
      node.goods.forEach(function(item) {
        /** @type {string} */
        var _result = "";
        /** @type {string} */
        var result = "";
        if (r ? 1 == item.type ? (_result += "[销]", sum += item.quantity, amount = self.accAdd(amount, self.accMul(item.truePrice, item.quantity)), previous = self.accAdd(previous, self.accMul(self.accSub(item.price, item.truePrice), item.quantity))) : 2 == item.type && (_result += "【退】", path += item.quantity,
        interval = self.accAdd(interval, self.accMul(item.truePrice, item.quantity)), now = self.accAdd(now, self.accMul(self.accSub(item.price, item.truePrice), item.quantity))) : v = self.accAdd(v, self.accMul(self.accSub(item.price, item.truePrice), item.quantity)), (!view || label.indexOf("color") > -1) &&
        (_result += (r ? "" : "  ") + item.colorName), (!view || label.indexOf("size") > -1) && (_result += (r ? "" : "  ") + item.sizeName), status.goodsDetail += _result, result += _result, boardState && (self.getBytesLength(container[1].currentSpace) < self.getBytesLength(result) && (status.goodsDetail += "\n", result = "")), !g) {
          var tag = item.price.toFixed(2)
        }
        var string = item.quantity.toString() + (item.unit ? item.unit : "");
        var str = item.truePrice.toFixed(2);
        var chunk = self.accMul(str, item.quantity).toFixed(2);
        if (!g) {
          var aString = item.discount.toString()
        }
        /** @type {number} */
        var nodeType = 1;
        var data = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(result));
        if (nodeType++, status.goodsDetail += data, result += data, label && label.indexOf("orig") > -1) {
          status.goodsDetail += tag;
          result += tag;
          data = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(result));
          nodeType++;
          status.goodsDetail += data;
          result += data;
        }
        status.goodsDetail += string;
        result += string;
        data = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(result));
        if (nodeType++, status.goodsDetail += data, result += data, label && label.indexOf("discount") > -1) {
          status.goodsDetail += aString;
          result += aString;
          data = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(result));
          nodeType++;
          status.goodsDetail += data;
          result += data;
        }
        status.goodsDetail += str;
        result += str;
        data = clone(self.getBytesLength(container[nodeType].currentSpace), self.getBytesLength(result));
        nodeType++;
        status.goodsDetail += data;
        result += data;
        status.goodsDetail += chunk;
        result += chunk;
        status.goodsDetail += "\n";
        count += item.quantity;
      });
    }), status.goodsDetail += cb(e), sum > 0) {
      var append = "销售：" + sum + "  " + join("lbCurrency")(amount.toFixed(2), collection.currencySymbol);
      /** @type {number} */
      var b = 0;
      /** @type {number} */
      var a = e / 2 - self.getBytesLength(append);
      for (;a > b;b++) {
        append += " ";
      }
      append += "退货：" + path + "  " + join("lbCurrency")(interval.toFixed(2), collection.currencySymbol);
      status.total += append + "\n\n";
    }
    var text = "合计  数量：" + count;
    if (e >= 40) {
      /** @type {number} */
      b = 0;
      /** @type {number} */
      a = e / 2 - self.getBytesLength(text);
      for (;a > b;b++) {
        text += " ";
      }
    } else {
      /** @type {string} */
      text = "数量：" + count + "  ";
    }
    if (text += "金额：", g) {
      text += join("lbCurrency")(scope.order.totalAmount.toFixed(2), collection.currencySymbol);
    } else {
      if (1 == setting) {
        var arg = scope.order.trueTotalAmount;
        text += join("lbCurrency")(Math.abs(arg).toFixed(2), collection.currencySymbol);
        if (scope.order.wipeZero) {
          arg = self.accSub(arg, scope.order.wipeZero);
        }
        if (scope.order.otherCost) {
          arg = self.accAdd(arg, scope.order.otherCost);
        }
        if (scope.order.wipeZero || scope.order.otherCost) {
          status.goodsDetail += text + "\n";
          status.goodsDetail += cb(e);
          /** @type {string} */
          text = "";
          text += "总金额  ：" + join("lbCurrency")(Math.abs(arg).toFixed(2), collection.currencySymbol);
        }
      } else {
        text += join("lbCurrency")(Math.abs(scope.order.trueTotalAmount).toFixed(2), collection.currencySymbol);
      }
      if (!g) {
        if (label) {
          if (label.indexOf("discountAmount") > -1) {
            v = r ? now - previous : v;
            text += "\n优惠金额：" + join("lbCurrency")(Math.abs(v).toFixed(2), collection.currencySymbol);
          }
        }
      }
    }
    return status.total += text + "\n", status;
  }
  /**
   * @param {Object} scope
   * @param {number} e
   * @param {boolean} view
   * @param {string} obj
   * @param {Array} container
   * @param {boolean} boardState
   * @param {number} path
   * @return {?}
   */
  function bind(scope, e, view, obj, container, boardState, path) {
    /**
     * @param {Array} data
     * @param {string} name
     * @param {Object} row
     * @return {undefined}
     */
    function ondata(data, name, row) {
      if (self.isArray(data) && row[name]) {
        /** @type {number} */
        var index = -1;
        /** @type {number} */
        var idx = 0;
        for (;idx < data.length;idx++) {
          if (data[idx][name] == row[name]) {
            /** @type {number} */
            index = idx;
          }
        }
        if (index != data.length - 1 && index > -1) {
          data.push(row);
          /** @type {number} */
          var i = data.length - 1;
          for (;i > index + 1;i--) {
            data[i] = data[i - 1];
          }
          /** @type {Object} */
          data[index + 1] = row;
        } else {
          data.push(row);
        }
      }
    }
    var status = {
      goodsDetail : "",
      total : ""
    };
    /** @type {boolean} */
    var success = 5 == path ? true : false;
    /** @type {boolean} */
    var sizeId = 2 == path ? true : false;
    /** @type {boolean} */
    var f = false;
    if (!view || obj.indexOf("goodsSn") > -1) {
      /** @type {boolean} */
      f = true;
    }
    /** @type {boolean} */
    var nowEndsWithSlash = false;
    if (!view || obj.indexOf("color") > -1) {
      /** @type {boolean} */
      nowEndsWithSlash = true;
    }
    /** @type {boolean} */
    var pathStartsWithSlash = false;
    if (!view || obj.indexOf("size") > -1) {
      /** @type {boolean} */
      pathStartsWithSlash = true;
    }
    var close = obj && obj.indexOf("discount") > -1;
    var hasHandler = obj && obj.indexOf("orig") > -1;
    /** @type {number} */
    var cssValue = 0;
    /** @type {number} */
    var initial = 0;
    /** @type {number} */
    var arg = 0;
    if (sizeId) {
      /** @type {number} */
      var caption = 0;
      /** @type {number} */
      var structure = 0;
      /** @type {number} */
      var property = 0;
      /** @type {number} */
      var unknown = 0;
    }
    /** @type {string} */
    var type = " ";
    var attributes = scope.orderGoods;
    /** @type {Array} */
    var items = [];
    /** @type {Array} */
    var files = [];
    if (nowEndsWithSlash && pathStartsWithSlash || !nowEndsWithSlash && pathStartsWithSlash) {
      /** @type {number} */
      var index = 0;
      for (;index < attributes.length;index++) {
        var file = self.fnCheckGtoreQty(files, "goodsSn", attributes[index].goodsSn);
        if (file) {
          var I = self.fnCheckGtoreQty(file.allSizeArr, "sizeId", attributes[index].sizeId);
          if (!I) {
            file.allSizeArr.push({
              sizeId : attributes[index].sizeId,
              sizeName : attributes[index].sizeName
            });
          }
        } else {
          files.push({
            goodsSn : attributes[index].goodsSn,
            content : "",
            allSizeArr : [{
              sizeId : attributes[index].sizeId,
              sizeName : attributes[index].sizeName
            }]
          });
        }
      }
      /** @type {number} */
      index = 0;
      for (;index < attributes.length;index++) {
        var data = self.getObjectByObject(items, {
          goodsSn : attributes[index].goodsSn,
          colorId : attributes[index].colorId
        });
        file = self.fnCheckGtoreQty(files, "goodsSn", attributes[index].goodsSn);
        if (data) {
          data.sizeArr.push({
            sizeId : attributes[index].sizeId,
            sizeName : attributes[index].sizeName,
            quantity : attributes[index].quantity
          });
        } else {
          data = {
            goodName : attributes[index].goodName,
            goodsSn : attributes[index].goodsSn,
            colorId : attributes[index].colorId,
            colorName : attributes[index].colorName,
            allSizeArr : [],
            sizeArr : [{
              sizeId : attributes[index].sizeId,
              sizeName : attributes[index].sizeName,
              quantity : attributes[index].quantity
            }],
            price : 0,
            discount : 0,
            quantity : 0,
            truePrice : 0,
            trueAmount : 0
          };
          if (ondata(items, "goodsSn", data), data.allSizeArr.length < file.allSizeArr.length) {
            /** @type {number} */
            var count = 0;
            /** @type {number} */
            var html = 0;
            /** @type {number} */
            var now = 0;
            /** @type {number} */
            var i = 0;
            /** @type {number} */
            var idx = 0;
            for (;idx < file.allSizeArr.length;idx++) {
              var options = self.getObjectByObject(attributes, {
                goodsSn : data.goodsSn,
                colorId : data.colorId,
                sizeId : file.allSizeArr[idx].sizeId
              });
              data.allSizeArr.push(sizeId && options ? {
                sizeId : file.allSizeArr[idx].sizeId,
                sizeName : file.allSizeArr[idx].sizeName,
                quantity : options ? options.quantity : 0,
                type : options.type
              } : {
                sizeId : file.allSizeArr[idx].sizeId,
                sizeName : file.allSizeArr[idx].sizeName,
                quantity : options ? options.quantity : 0
              });
              if (sizeId) {
                if (options) {
                  if (1 == options.type) {
                    count -= options.quantity;
                    html -= self.accMul(options.quantity, options.truePrice);
                    now -= options.trueAmount;
                    i -= self.accMul(options.quantity, options.price);
                    caption = self.accAdd(caption, options.quantity);
                    structure = self.accAdd(structure, self.accMul(options.truePrice, options.quantity));
                    cssValue = self.accAdd(cssValue, options.quantity);
                    initial = self.accSub(initial, options.trueAmount);
                  } else {
                    if (2 == options.type) {
                      count = self.accAdd(count, options.quantity);
                      html = self.accAdd(html, self.accMul(options.quantity, options.truePrice));
                      now = self.accAdd(now, options.trueAmount);
                      i = self.accAdd(i, self.accMul(options.quantity, options.price));
                      property = self.accAdd(property, options.quantity);
                      unknown = self.accAdd(unknown, self.accMul(options.truePrice, options.quantity));
                      cssValue = self.accAdd(cssValue, options.quantity);
                      initial = self.accAdd(initial, options.trueAmount);
                    }
                  }
                }
              } else {
                count = self.accAdd(count, options ? options.quantity : 0);
                html = self.accAdd(html, options ? self.accMul(options.quantity, options.truePrice) : 0);
                now = self.accAdd(now, options ? success ? options.amount : options.trueAmount : 0);
                if (!success) {
                  i = self.accAdd(i, options ? self.accMul(options.quantity, options.price) : 0);
                }
                cssValue = self.accAdd(cssValue, options ? options.quantity : 0);
                initial = self.accAdd(initial, options ? success ? options.amount : options.trueAmount : 0);
              }
            }
            /** @type {number} */
            data.quantity = count;
            data.truePrice = 0 == data.quantity ? html : self.accDiv(html, data.quantity);
            /** @type {number} */
            data.trueAmount = now;
            if (!success) {
              data.price = self.accDiv(i, data.quantity);
              data.discount = 0 == i ? 0 : self.accMul(self.accDiv(html, i), 100);
              arg = self.accAdd(arg, self.accSub(html, i));
            }
          }
        }
      }
    } else {
      if (nowEndsWithSlash && !pathStartsWithSlash || !nowEndsWithSlash && !pathStartsWithSlash) {
        /** @type {number} */
        index = 0;
        for (;index < attributes.length;index++) {
          file = self.fnCheckGtoreQty(files, "goodsSn", attributes[index].goodsSn);
          if (!file) {
            files.push({
              goodsSn : attributes[index].goodsSn,
              content : "",
              allSizeArr : []
            });
          }
        }
        /** @type {number} */
        index = 0;
        for (;index < attributes.length;index++) {
          data = {
            goodName : attributes[index].goodName,
            goodsSn : attributes[index].goodsSn,
            colorId : attributes[index].colorId,
            colorName : attributes[index].colorName,
            allSizeArr : [],
            sizeArr : [],
            price : attributes[index].price,
            discount : attributes[index].discount,
            quantity : attributes[index].quantity,
            truePrice : attributes[index].truePrice,
            trueAmount : success ? attributes[index].amount : attributes[index].trueAmount
          };
          items.push(data);
          cssValue = self.accAdd(cssValue, attributes[index].quantity);
          initial = self.accAdd(initial, success ? attributes[index].amount : attributes[index].trueAmount);
        }
      }
    }
    var r;
    var x;
    var w;
    var h;
    var n;
    /** @type {number} */
    var child = 0;
    /** @type {number} */
    var maxLength = 0;
    /** @type {number} */
    var maxh = 0;
    /** @type {number} */
    var g = 0;
    /** @type {number} */
    var y = 0;
    /** @type {number} */
    var maxw = 0;
    /** @type {number} */
    var max = 0;
    /** @type {Array} */
    var matches = [];
    child = self.getBytesLength("商品" + type);
    if (nowEndsWithSlash) {
      maxLength = self.getBytesLength("颜色" + type);
    }
    /** @type {number} */
    index = 0;
    for (;index < items.length;index++) {
      if (f) {
        var rad = self.getBytesLength(items[index].goodName.toString() + "/" + items[index].goodsSn.toString() + type)
      } else {
        rad = self.getBytesLength(items[index].goodName.toString() + type);
      }
      if (child = rad > child ? rad : child, nowEndsWithSlash) {
        var lineLength = self.getBytesLength(items[index].colorName.toString() + type);
        maxLength = lineLength > maxLength ? lineLength : maxLength;
      }
      /** @type {number} */
      idx = 0;
      for (;idx < items[index].allSizeArr.length;idx++) {
        var elem = self.getBytesLength(items[index].allSizeArr[idx].quantity.toString() + type);
        if (sizeId) {
          if (1 == items[index].allSizeArr[idx].type) {
            elem += self.getBytesLength("[销]");
          }
        }
        if (matches[idx]) {
          if (elem > matches[idx]) {
            matches[idx] = elem;
          }
        } else {
          matches.push(elem);
        }
      }
      /** @type {string} */
      var url = items[index].quantity.toString() + (items[index].unit ? items[index].unit : "  ") + type;
      var key = items[index].price.toFixed(2) + type;
      var msg = items[index].truePrice.toFixed(2) + type;
      var c = items[index].discount.toFixed(2) + type;
      var prop = items[index].trueAmount.toFixed(2) + type;
      h = self.getBytesLength(url);
      maxh = h > maxh ? h : maxh;
      if (hasHandler) {
        r = self.getBytesLength(key);
        g = r > g ? r : g;
      } else {
        /** @type {number} */
        r = 0;
        /** @type {number} */
        g = 0;
      }
      x = self.getBytesLength(msg);
      y = x > y ? x : y;
      w = self.getBytesLength(c);
      maxw = w > maxw ? w : maxw;
      n = self.getBytesLength(prop);
      max = n > max ? n : max;
    }
    /** @type {number} */
    var parent = 0;
    /** @type {number} */
    index = 0;
    for (;index < files.length;index++) {
      file = files[index];
      /** @type {number} */
      var ut = 0;
      /** @type {number} */
      idx = 0;
      for (;idx < file.allSizeArr.length;idx++) {
        ut += self.getBytesLength(file.allSizeArr[idx].sizeName.toString() + type);
        if (matches[idx] < self.getBytesLength(file.allSizeArr[idx].sizeName.toString() + type)) {
          matches[idx] = self.getBytesLength(file.allSizeArr[idx].sizeName.toString() + type);
        }
      }
    }
    /** @type {number} */
    index = 0;
    for (;index < matches.length;index++) {
      parent += matches[index];
    }
    var s = child + maxLength + parent + maxh + g + y + maxw + max;
    if (!close) {
      s -= maxw;
    }
    /** @type {string} */
    var m = "";
    /** @type {number} */
    var end = close ? 6 : 5;
    if (e > s) {
      /** @type {number} */
      var tagSeparatorIndex = (e - s) / (matches.length + end);
      tagSeparatorIndex -= tagSeparatorIndex % 1;
      /** @type {number} */
      index = 0;
      for (;tagSeparatorIndex > index;index++) {
        m += " ";
      }
    }
    /** @type {string} */
    var len = "商品" + type;
    if (nowEndsWithSlash) {
      /** @type {string} */
      var str = "颜色" + type
    } else {
      /** @type {string} */
      str = "";
    }
    len += clone(child, self.getBytesLength(len));
    str += clone(maxLength, self.getBytesLength(str));
    /** @type {string} */
    var value = len + m + str + m;
    /** @type {number} */
    index = 0;
    for (;index < files.length;index++) {
      file = files[index];
      /** @type {number} */
      idx = 0;
      for (;idx < file.allSizeArr.length;idx++) {
        file.content += file.allSizeArr[idx].sizeName.toString() + type;
        file.content += clone(matches[idx], self.getBytesLength(file.allSizeArr[idx].sizeName.toString() + type));
        file.content += m;
      }
      file.content += clone(parent + self.getBytesLength(m) * matches.length, self.getBytesLength(file.content));
    }
    /** @type {number} */
    var li = 0;
    /** @type {number} */
    index = 0;
    for (;index < files.length;index++) {
      if (status.goodsDetail += len, status.goodsDetail += m, status.goodsDetail += str, status.goodsDetail += m, status.goodsDetail += files[index].content, status.goodsDetail += clone(parent + self.getBytesLength(m) * matches.length, self.getBytesLength(files[index].content)), hasHandler) {
        /** @type {string} */
        var pad = close ? "原价" : "原价";
        /** @type {string} */
        var root = pad + type + clone(g, self.getBytesLength(pad + type));
        status.goodsDetail += root;
        status.goodsDetail += m;
      }
      /** @type {string} */
      var text = "数量" + type + clone(maxh, self.getBytesLength("数量" + type));
      if (status.goodsDetail += text, status.goodsDetail += m, close) {
        /** @type {string} */
        var append = "折扣%" + type + clone(maxw, self.getBytesLength("折扣%" + type));
        status.goodsDetail += append;
        status.goodsDetail += m;
      }
      /** @type {string} */
      var _ = close || hasHandler ? "折后价" : "单价";
      /** @type {string} */
      var className = _ + type + clone(y, self.getBytesLength(_ + type));
      status.goodsDetail += className;
      status.goodsDetail += m;
      /** @type {string} */
      var b = "小计" + type + clone(max, self.getBytesLength("小计" + type));
      status.goodsDetail += b;
      status.goodsDetail += m;
      status.goodsDetail += "\n";
      /** @type {number} */
      idx = li;
      for (;idx < items.length;idx++) {
        if (items[idx].goodsSn != files[index].goodsSn) {
          /** @type {number} */
          li = idx;
          break;
        }
        if (f) {
          status.goodsDetail += items[idx].goodName.toString() + "/" + items[idx].goodsSn.toString() + type;
          status.goodsDetail += m;
          /** @type {string} */
          var result = items[idx].goodName.toString() + "/" + items[idx].goodsSn.toString() + type;
        } else {
          status.goodsDetail += items[idx].goodName.toString() + type;
          status.goodsDetail += m;
          result = items[idx].goodName.toString() + type;
        }
        result += callback(child, self.getBytesLength(result), status);
        result += m;
        if (nowEndsWithSlash) {
          status.goodsDetail += items[idx].colorName.toString() + type;
          status.goodsDetail += m;
          result += items[idx].colorName.toString() + type;
          result += m;
          result += callback(maxLength, self.getBytesLength(items[idx].colorName.toString() + type), status);
        } else {
          status.goodsDetail += m;
          result += m;
        }
        /** @type {string} */
        var button = "";
        /** @type {number} */
        var p = 0;
        for (;p < items[idx].allSizeArr.length;p++) {
          if (sizeId && 1 == items[idx].allSizeArr[p].type) {
            status.goodsDetail += items[idx].allSizeArr[p].quantity.toString() + "[销]" + type;
            result += items[idx].allSizeArr[p].quantity.toString() + "[销]" + type;
          } else {
            status.goodsDetail += items[idx].allSizeArr[p].quantity.toString() + type;
            result += items[idx].allSizeArr[p].quantity.toString() + type;
          }
          status.goodsDetail += m;
          result += m;
          button += items[idx].allSizeArr[p].sizeName.toString() + type;
          button += m;
          button += clone(matches[p], self.getBytesLength(items[idx].allSizeArr[p].sizeName.toString() + type));
          result += callback(self.getBytesLength(value + button), self.getBytesLength(result), status);
        }
        result += callback(parent + self.getBytesLength(m) * matches.length, self.getBytesLength(button), status);
        if (hasHandler) {
          status.goodsDetail += items[idx].price < 0 ? (-items[idx].price).toFixed(2) + " " + type : items[idx].price.toFixed(2) + type;
          status.goodsDetail += m;
          result += items[idx].price.toFixed(2) + type;
          result += callback(self.getBytesLength(root), self.getBytesLength(items[idx].price.toFixed(2) + type), status);
        }
        status.goodsDetail += items[idx].quantity < 0 ? -items[idx].quantity + " " + type : items[idx].quantity + type;
        status.goodsDetail += items[index].unit ? items[index].unit : "  ";
        status.goodsDetail += m;
        result += items[idx].quantity + type;
        result += m;
        result += callback(self.getBytesLength(text), self.getBytesLength(items[idx].quantity.toString() + (items[index].unit ? items[index].unit : "  ") + type), status);
        if (close) {
          status.goodsDetail += items[idx].discount < 0 ? (-items[idx].discount).toFixed(2) + " " + type : items[idx].discount.toFixed(2) + type;
          status.goodsDetail += m;
          result += items[idx].discount.toFixed(2) + type;
          result += callback(self.getBytesLength(append), self.getBytesLength(items[idx].discount.toFixed(2) + type), status);
        }
        status.goodsDetail += items[idx].truePrice < 0 ? (-items[idx].truePrice).toFixed(2) + " " + type : items[idx].truePrice.toFixed(2) + type;
        status.goodsDetail += m;
        result += items[idx].truePrice.toFixed(2) + type;
        result += callback(self.getBytesLength(className), self.getBytesLength(items[idx].truePrice.toFixed(2) + type), status);
        status.goodsDetail += items[idx].trueAmount < 0 ? (-items[idx].trueAmount).toFixed(2) + " " + type : items[idx].trueAmount.toFixed(2) + type;
        status.goodsDetail += m;
        result += items[idx].trueAmount.toFixed(2) + type;
        result += callback(self.getBytesLength(b), self.getBytesLength(items[idx].trueAmount.toFixed(2) + type), status);
        status.goodsDetail += "\n";
      }
      status.goodsDetail += cb(e);
    }
    if (sizeId) {
      if (caption > 0) {
        status.total += "销售：" + caption + " " + structure + "  退货：" + property + " " + unknown + "\n";
      }
    }
    /** @type {string} */
    var ch = "合计  数量：" + cssValue;
    if (e >= 40) {
      /** @type {number} */
      index = 0;
      /** @type {number} */
      idx = e / 2 - self.getBytesLength(ch);
      for (;idx > index;index++) {
        ch += " ";
      }
    } else {
      /** @type {string} */
      ch = "数量：" + cssValue + "  ";
    }
    return ch += "金额：" + join("lbCurrency")(Math.abs(scope.order.trueTotalAmount).toFixed(2), collection.currencySymbol), status.total += ch, !success && (obj && (obj.indexOf("discountAmount") > -1 && (status.total += "\n优惠金额：" + join("lbCurrency")(Math.abs(arg).toFixed(2), collection.currencySymbol)))), status.total += "\n", status;
  }
  /**
   * @param {Object} object
   * @param {number} r
   * @param {boolean} val
   * @param {string} obj
   * @param {Array} max
   * @param {boolean} regex
   * @return {?}
   */
  function toString(object, r, val, obj, max, regex) {
    var me = {
      goodsDetail : "",
      total : ""
    };
    /** @type {number} */
    var g = 0;
    max.forEach(function(button) {
      g += self.getBytesLength(button.name);
    });
    max.forEach(function(chunk) {
      /** @type {number} */
      var t = 0;
      for (;t < (r - g) * chunk.sizeToSplit;t++) {
        me.goodsDetail += " ";
      }
      me.goodsDetail += chunk.name;
    });
    me.goodsDetail += "\n";
    var x;
    var h;
    var p;
    /** @type {number} */
    var y = 0;
    /** @type {number} */
    var height = 0;
    /** @type {number} */
    var paramMax = 0;
    if (object.orderGoods.forEach(function(test) {
      /** @type {string} */
      var i = " " + test.transferNumber.toString() + " ";
      /** @type {string} */
      var r = " " + (test.outBeforeNumber ? test.outBeforeNumber.toString() : "0") + " ";
      /** @type {string} */
      var c = " " + (test.inBeforeNumber ? test.inBeforeNumber.toString() : "0") + " ";
      x = self.getBytesLength(i);
      y = x > y ? x : y;
      h = self.getBytesLength(r);
      height = h > height ? h : height;
      p = self.getBytesLength(c);
      paramMax = p > paramMax ? p : paramMax;
    }), regex) {
      if (r > y + height + paramMax) {
        /** @type {number} */
        var len = Math.floor((r - y - height - paramMax) / 4);
        height += 2 * len;
        paramMax += len;
        y += len;
      }
    } else {
      if (r > y + height + paramMax) {
        /** @type {number} */
        len = Math.floor((3 * r / 8 - y - height - paramMax) / 3);
        height += len;
        paramMax += 2 * len;
        y += 2 * len;
      }
    }
    /** @type {number} */
    var output = 0;
    return object.orderGoods.forEach(function(node) {
      /** @type {string} */
      var text = "";
      if ((!val || obj.indexOf("goodsSn") > -1) && (text += self.trim(node.goodsSn) + "/"), text += node.goodName, (!val || obj.indexOf("color") > -1) && (text += "  " + node.colorName), (!val || obj.indexOf("size") > -1) && (text += "  " + node.sizeName), me.goodsDetail += text, regex) {
        me.goodsDetail += "\n";
      } else {
        if (2 * r * max[0].sizeToSplit - self.getBytesLength(text) >= 0) {
          /** @type {number} */
          var b = 0;
          for (;b < 2 * r * max[0].sizeToSplit - self.getBytesLength(text);b++) {
            me.goodsDetail += " ";
          }
        } else {
          me.goodsDetail += "\n";
          /** @type {number} */
          b = 0;
          for (;b < 2 * r * max[0].sizeToSplit;b++) {
            me.goodsDetail += " ";
          }
        }
      }
      /** @type {string} */
      var l = " " + node.transferNumber.toString() + " ";
      /** @type {string} */
      var append = " " + (node.outBeforeNumber ? node.outBeforeNumber.toString() : "0") + " ";
      /** @type {string} */
      var part = " " + (node.inBeforeNumber ? node.inBeforeNumber.toString() : "0") + " ";
      /** @type {number} */
      b = 0;
      /** @type {number} */
      var a = height - self.getBytesLength(append);
      for (;a > b;b++) {
        me.goodsDetail += " ";
      }
      me.goodsDetail += append;
      /** @type {number} */
      b = 0;
      /** @type {number} */
      a = paramMax - self.getBytesLength(part);
      for (;a > b;b++) {
        me.goodsDetail += " ";
      }
      me.goodsDetail += part;
      /** @type {number} */
      b = 0;
      /** @type {number} */
      a = y - self.getBytesLength(l);
      for (;a > b;b++) {
        me.goodsDetail += " ";
      }
      me.goodsDetail += l;
      me.goodsDetail += "\n";
      output += node.transferNumber;
    }), me.goodsDetail += cb(r), me.total = $(r, "调拨合计：   " + output + "  ", "right"), me;
  }
  /**
   * @param {Object} query
   * @param {number} e
   * @param {boolean} path
   * @param {string} ret
   * @param {Array} list
   * @param {boolean} regex
   * @return {?}
   */
  function validate(query, e, path, ret, list, regex) {
    var data = {
      goodsDetail : "",
      total : ""
    };
    /** @type {number} */
    var s = 0;
    list.forEach(function(button) {
      s += self.getBytesLength(button.name);
    });
    list.forEach(function(transform) {
      /** @type {number} */
      var t = 0;
      for (;t < (e - s) * transform.sizeToSplit;t++) {
        data.goodsDetail += " ";
      }
      data.goodsDetail += transform.name;
    });
    data.goodsDetail += "\n";
    /** @type {Array} */
    var matched = [];
    query.orderGoods.forEach(function(v) {
      /** @type {boolean} */
      var r = false;
      /** @type {number} */
      var name_fragment = 0;
      /** @type {number} */
      var cnl = matched.length;
      for (;cnl > name_fragment;name_fragment++) {
        var varname = matched[name_fragment].goodsSn;
        if (v.goodsSn == varname) {
          /** @type {boolean} */
          r = true;
          matched[name_fragment].goods.push(self.getPropertyObj(v, ["colorId", "sizeId", "colorName", "sizeName", "transferNumber", "outBeforeNumber", "inBeforeNumber", "unit"]));
        }
      }
      if (!r) {
        var elem = {};
        /** @type {Array} */
        elem.goods = [];
        elem.goods.push(self.getPropertyObj(v, ["colorId", "sizeId", "colorName", "sizeName", "transferNumber", "outBeforeNumber", "inBeforeNumber", "unit"]));
        elem.goodName = v.goodName;
        elem.goodsSn = v.goodsSn;
        elem.barCode = v.barCode;//条码
        matched.push(elem);
      }
    });
    /** @type {number} */
    var output = 0;
    return matched.forEach(function(node) {
      /** @type {string} */
      var output = "";
      if (!path || ret.indexOf("goodsSn") > -1) {
        output += self.trim(node.goodsSn) + "/";
      }
      output += node.goodName;
      data.goodsDetail += output;
      data.goodsDetail += "\n";
      var x;
      var p;
      var h;
      /** @type {number} */
      var y = 0;
      /** @type {number} */
      var paramMax = 0;
      /** @type {number} */
      var maxh = 0;
      if (node.goods.forEach(function(test) {
        /** @type {string} */
        var i = " " + test.transferNumber.toString() + " ";
        /** @type {string} */
        var c = " " + (test.outBeforeNumber ? test.outBeforeNumber.toString() : "0") + " ";
        /** @type {string} */
        var r = " " + (test.inBeforeNumber ? test.inBeforeNumber.toString() : "0") + " ";
        x = self.getBytesLength(i);
        y = x > y ? x : y;
        p = self.getBytesLength(c);
        paramMax = p > paramMax ? p : paramMax;
        h = self.getBytesLength(r);
        maxh = h > maxh ? h : maxh;
      }), regex) {
        if (e > y + paramMax + maxh) {
          /** @type {number} */
          var len = Math.floor((e * (1 - list[0].sizeToSplit) - y - paramMax - maxh) / 3);
          paramMax += len;
          maxh += len;
          y += len;
        }
      } else {
        if (e > y + paramMax + maxh) {
          /** @type {number} */
          len = Math.floor((3 * e / 8 - y - paramMax - maxh) / 3);
          paramMax += len;
          maxh += 2 * len;
          y += 2 * len;
        }
      }
      node.goods.forEach(function(node) {
        /** @type {string} */
        var append = "";
        if ((!path || ret.indexOf("color") > -1) && (append += "  " + node.colorName), (!path || ret.indexOf("size") > -1) && (append += "  " + node.sizeName), data.goodsDetail += append, regex) {
          if (e * list[0].sizeToSplit - self.getBytesLength(append) >= 0) {
            /** @type {number} */
            var b = 0;
            for (;b < e * list[0].sizeToSplit - self.getBytesLength(append);b++) {
              data.goodsDetail += " ";
            }
          } else {
            data.goodsDetail += "\n";
            /** @type {number} */
            b = 0;
            for (;b < e * list[0].sizeToSplit;b++) {
              data.goodsDetail += " ";
            }
          }
        } else {
          if (2 * e * list[0].sizeToSplit - self.getBytesLength(append) >= 0) {
            /** @type {number} */
            b = 0;
            for (;b < 2 * e * list[0].sizeToSplit - self.getBytesLength(append);b++) {
              data.goodsDetail += " ";
            }
          } else {
            data.goodsDetail += "\n";
            /** @type {number} */
            b = 0;
            for (;b < 2 * e * list[0].sizeToSplit;b++) {
              data.goodsDetail += " ";
            }
          }
        }
        /** @type {string} */
        var n = " " + node.transferNumber.toString() + " ";
        /** @type {string} */
        var ch = " " + (node.outBeforeNumber ? node.outBeforeNumber.toString() : "0") + " ";
        /** @type {string} */
        var str = " " + (node.inBeforeNumber ? node.inBeforeNumber.toString() : "0") + " ";
        /** @type {number} */
        b = 0;
        /** @type {number} */
        var a = paramMax - self.getBytesLength(ch);
        for (;a > b;b++) {
          data.goodsDetail += " ";
        }
        data.goodsDetail += ch;
        /** @type {number} */
        b = 0;
        /** @type {number} */
        a = maxh - self.getBytesLength(str);
        for (;a > b;b++) {
          data.goodsDetail += " ";
        }
        data.goodsDetail += str;
        /** @type {number} */
        b = 0;
        /** @type {number} */
        a = y - self.getBytesLength(n);
        for (;a > b;b++) {
          data.goodsDetail += " ";
        }
        data.goodsDetail += n;
        data.goodsDetail += "\n";
        output += node.transferNumber;
      });
    }), data.goodsDetail += cb(e), data.total = $(e, "调拨合计：   " + output + "  ", "right"), data;
  }
  /**
   * @param {?} e
   * @param {boolean} event
   * @param {string} param
   * @return {?}
   */
  function onload(e, event, param) {
    /** @type {string} */
    var ret = "";
    return event ? param && (ret += $(e, param), ret += "\n") : (ret += "辛巴手机版" + (ionic.Platform.isAndroid() ? "Android版" : "iOS版") + "  V" + collection.innerAppVersion, ret += "\n"), ret;
  }
  /**
   * @param {string} set
   * @param {string} data
   * @param {string} path
   * @return {?}
   */
  function save(set, data, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      var arrayClass;
      var direction;
      var tr;
      var $P;
      var obj;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var opts = false;
      if (w.object) {
        if (arrayClass = w.object.printType ? w.object.printType : "goodsGroupPrint", direction = w.object.templateType, direction.indexOf("ep-basic") > -1) {
          var max = direction.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          direction = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        obj = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        opts = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = direction;
      } else {
        /** @type {string} */
        direction = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      /** @type {string} */
      var id = "";
      if (!opts || obj.indexOf("color") > -1) {
        id += "color,";
      }
      if (!opts || obj.indexOf("size") > -1) {
        id += "size";
      }
      /** @type {string} */
      var buff = "";
      switch(path) {
        case ide.saleOrder:
          /** @type {string} */
          buff = "/KEY459?ordersSn=";
          break;
        case ide.saleReturnOrder:
          /** @type {string} */
          buff = "/KEY460?ordersSn=";
      }
      db.post(buff + data + "&enableColumns=" + id).success(function(scope) {
        if (null == scope.order) {
          return self.toastShow("找不到指定的数据"), dfrd.reject(), dfrd.promise;
        }
        /** @type {Array} */
        var $ul = [{
          name : "商品",
          sizeToSplit : 0.2
        }, {
          name : "数量",
          sizeToSplit : 0.4
        }, {
          name : "单价",
          sizeToSplit : 0.1
        }, {
          name : "金额",
          sizeToSplit : 0.1
        }];
        var f1SpecialConvert = obj && obj.indexOf("discount") > -1;
        var f2SpecialConvert = obj && obj.indexOf("orig") > -1;
        if (f1SpecialConvert && !f2SpecialConvert) {
          /** @type {Array} */
          $ul = [{
            name : "商品",
            sizeToSplit : 0.1
          }, {
            name : "数量",
            sizeToSplit : 0.4
          }, {
            name : "折扣%",
            sizeToSplit : 0.1
          }, {
            name : "折后价",
            sizeToSplit : 0.1
          }, {
            name : "金额",
            sizeToSplit : 0.1
          }];
        } else {
          if (!f1SpecialConvert && f2SpecialConvert) {
            /** @type {Array} */
            $ul = [{
              name : "商品",
              sizeToSplit : 0.1
            }, {
              name : "原价",
              sizeToSplit : 0.4
            }, {
              name : "数量",
              sizeToSplit : 0.1
            }, {
              name : "折后价",
              sizeToSplit : 0.1
            }, {
              name : "金额",
              sizeToSplit : 0.1
            }];
          } else {
            if (f1SpecialConvert) {
              if (f2SpecialConvert) {
                /** @type {Array} */
                $ul = [{
                  name : "商品",
                  sizeToSplit : 0.1
                }, {
                  name : "原价",
                  sizeToSplit : 0.3
                }, {
                  name : "数量",
                  sizeToSplit : 0.1
                }, {
                  name : "折扣%",
                  sizeToSplit : 0.1
                }, {
                  name : "折后价",
                  sizeToSplit : 0.1
                }, {
                  name : "金额",
                  sizeToSplit : 0.1
                }];
              }
            }
          }
        }
        /** @type {boolean} */
        var boardState = true;
        if (opts) {
          if (direction) {
            if ("58mm" == direction) {
              /** @type {number} */
              e = 32;
              /** @type {Array} */
              $ul = [{
                name : "商品",
                sizeToSplit : 1 / 8
              }, {
                name : "数量",
                sizeToSplit : 1 / 8
              }, {
                name : "单价",
                sizeToSplit : 0.25
              }, {
                name : "金额",
                sizeToSplit : 0.25
              }];
              if (f1SpecialConvert && !f2SpecialConvert) {
                /** @type {Array} */
                $ul = [{
                  name : "商品",
                  sizeToSplit : 0.1
                }, {
                  name : "数量",
                  sizeToSplit : 1 / 8
                }, {
                  name : "折扣%",
                  sizeToSplit : 1 / 8
                }, {
                  name : "折后价",
                  sizeToSplit : 1 / 8
                }, {
                  name : "金额",
                  sizeToSplit : 1 / 8
                }];
              } else {
                if (!f1SpecialConvert && f2SpecialConvert) {
                  /** @type {Array} */
                  $ul = [{
                    name : "商品",
                    sizeToSplit : 0.1
                  }, {
                    name : "原价",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "数量",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "折后价",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "金额",
                    sizeToSplit : 1 / 8
                  }];
                } else {
                  if (f1SpecialConvert) {
                    if (f2SpecialConvert) {
                      /** @type {Array} */
                      $ul = [{
                        name : "商品",
                        sizeToSplit : 1 / 12
                      }, {
                        name : "原价",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "数量",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "折扣%",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "折后价",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "金额",
                        sizeToSplit : 1 / 8
                      }];
                    }
                  }
                }
              }
            } else {
              if ("80mm" == direction) {
                /** @type {number} */
                e = 48;
              } else {
                if ("110mm" == direction) {
                  /** @type {number} */
                  e = 68;
                  /** @type {boolean} */
                  boardState = false;
                } else {
                  if ("ep-basic" == direction) {
                    /** @type {number} */
                    e = 100;
                    /** @type {boolean} */
                    boardState = false;
                    /** @type {Array} */
                    $ul = [{
                      name : "商品",
                      sizeToSplit : 0.25
                    }, {
                      name : "数量",
                      sizeToSplit : 3 / 8
                    }, {
                      name : "单价",
                      sizeToSplit : 1 / 8
                    }, {
                      name : "金额",
                      sizeToSplit : 1 / 8
                    }];
                    if (f1SpecialConvert && !f2SpecialConvert) {
                      /** @type {Array} */
                      $ul = [{
                        name : "商品",
                        sizeToSplit : 0.25
                      }, {
                        name : "数量",
                        sizeToSplit : 0.25
                      }, {
                        name : "折扣%",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "折后价",
                        sizeToSplit : 1 / 8
                      }, {
                        name : "金额",
                        sizeToSplit : 1 / 8
                      }];
                    } else {
                      if (!f1SpecialConvert && f2SpecialConvert) {
                        /** @type {Array} */
                        $ul = [{
                          name : "商品",
                          sizeToSplit : 0.25
                        }, {
                          name : "原价",
                          sizeToSplit : 0.25
                        }, {
                          name : "数量",
                          sizeToSplit : 1 / 8
                        }, {
                          name : "折后价",
                          sizeToSplit : 1 / 8
                        }, {
                          name : "金额",
                          sizeToSplit : 1 / 8
                        }];
                      } else {
                        if (f1SpecialConvert) {
                          if (f2SpecialConvert) {
                            /** @type {Array} */
                            $ul = [{
                              name : "商品",
                              sizeToSplit : 0.25
                            }, {
                              name : "原价",
                              sizeToSplit : 0.25
                            }, {
                              name : "数量",
                              sizeToSplit : 0.5 / 8
                            }, {
                              name : "折扣%",
                              sizeToSplit : 1 / 8
                            }, {
                              name : "折后价",
                              sizeToSplit : 0.5 / 8
                            }, {
                              name : "金额",
                              sizeToSplit : 1 / 8
                            }];
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        var data = {
          title : "\n",
          content : "\n",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : direction
        };
        if (max) {
          data.pageSize = max;
        }
        var contents = JSpec.localStorage.PrintQRCode;
        if (contents) {
          data.qrCode = angular.fromJson(contents);
        }
        if ("ep-basic" == data.printTpl) {
          data.title += $(e / 2, set, "center");
          data.title += path === ide.saleOrder ? $(e / 2, "销售单", "center") : $(e / 2, "销售退货单", "center");
        } else {
          data.title += set + "\n";
          data.title += path === ide.saleOrder ? "销售单\n" : "销售退货单\n";
        }
        if (opts) {
          if (tr) {
            data.content += $(e, tr);
            data.content += "\n";
          }
        }
        /** @type {number} */
        var B = 0;
        /** @type {string} */
        var length = "";
        /** @type {string} */
        var ret = "";
        /** @type {string} */
        var duration = "";
        if (!opts || obj.indexOf("depotName") > -1) {
          B++;
          /** @type {string} */
          length = "仓库：" + scope.order.depotName;
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("clientName") > -1) {
          B++;
          /** @type {string} */
          length = "客户：" + scope.order.clientName;
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("contactNumber") > -1) {
          B++;
          /** @type {string} */
          length = "客户联系方式：";
          length += scope.order.cellPhone ? scope.order.cellPhone : scope.order.clientPhone ? scope.order.clientPhone : "";
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("salerName") > -1) {
          B++;
          /** @type {string} */
          length = "销售员：" + scope.order.salerName;
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("handlerName") > -1) {
          B++;
          /** @type {string} */
          length = "制单人：" + scope.order.handlerName;
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("ordersSn") > -1) {
          B++;
          /** @type {string} */
          length = "单号：" + scope.order.ordersSn;
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("updateTime") > -1) {
          B++;
          length = "业务日期：" + join("date")(scope.order.businessTime, "yyyy-MM-dd HH:mm:ss");
          if ("ep-basic" == direction && B % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
          } else {
            ret += length;
            ret += "ep-basic" != direction ? "\n" : "";
          }
        }
        if ("\n" != ret.charAt(ret.length - 1)) {
          ret += "\n";
        }
        data.content += ret;
        data.content += cb(e);
        /** @type {boolean} */
        var goodsGroupPrint = "goodsGroupPrint" == arrayClass;
        /** @type {boolean} */
        var isArr = "sizeHorizonPrint" == arrayClass;
        if (isArr) {
          var result = bind(scope, e, opts, obj, $ul, boardState, path);
          data.content += result.goodsDetail;
          data.total += result.total;
        } else {
          if (goodsGroupPrint) {
            result = start(scope, e, opts, obj, $ul, boardState, path);
            data.content += result.goodsDetail;
            data.total += result.total;
          } else {
            result = render(scope, e, opts, obj, $ul, boardState, path);
            data.content += result.goodsDetail;
            data.total += result.total;
          }
        }
        data.footer += cb(e);
        if (path === ide.saleOrder) {
          /** @type {number} */
          B = 0;
          /** @type {string} */
          length = "";
          /** @type {string} */
          ret = "";
          /** @type {string} */
          duration = "";
          if (scope.order.wipeZero) {
            B++;
            length = "抹零金额： " + join("lbCurrency")(scope.order.wipeZero.toFixed(2), collection.currencySymbol);
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              duration = length;
            }
          }
          if (scope.order.otherCost) {
            B++;
            length = "其他费用： " + scope.order.otherAccountItemName + "  " + join("lbCurrency")(scope.order.otherCost.toFixed(2), collection.currencySymbol);
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              duration = length;
            }
          }
          if (!opts || obj.indexOf("alreadyPaid") > -1) {
            B++;
            length = "实收金额： " + join("lbCurrency")(scope.order.alreadyPaid.toFixed(2), collection.currencySymbol);
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              duration = length;
            }
          }
          if (!opts || obj.indexOf("accountName") > -1) {
            B++;
            /** @type {string} */
            length = "结算账户：" + scope.order.accountName;
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              /** @type {string} */
              duration = length;
            }
          }
          if ("\n" != ret.charAt(ret.length - 1)) {
            ret += "\n";
          }
          data.footer += ret;
          if (!opts || obj.indexOf("deliveryDesc") > -1) {
            if (scope.order.deliveryDesc) {
              data.footer += "发货方式：" + scope.order.deliveryDesc.replace(/\&nbsp;/g, " ") + "\n";
            }
          }
        } else {
          /** @type {number} */
          B = 0;
          /** @type {string} */
          length = "";
          /** @type {string} */
          ret = "";
          /** @type {string} */
          duration = "";
          if (!opts || obj.indexOf("alreadyPaid") > -1) {
            if (scope.order.wipeZero) {
              B++;
              length = "抹零金额： " + join("lbCurrency")(scope.order.wipeZero.toFixed(2), collection.currencySymbol);
              if ("ep-basic" == direction && B % 2 == 0) {
                ret += fn(e, length, "right", duration);
                ret += "\n";
                /** @type {string} */
                duration = "";
              } else {
                ret += length;
                ret += "ep-basic" != direction ? "\n" : "";
                duration = length;
              }
            }
            B++;
            length = scope.order.alreadyPaid >= 0 ? "本单退款： " + join("lbCurrency")(scope.order.alreadyPaid.toFixed(2), collection.currencySymbol) : "本单收款： " + join("lbCurrency")(Math.abs(scope.order.alreadyPaid.toFixed(2)), collection.currencySymbol);
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              duration = length;
            }
          }
          if (!opts || obj.indexOf("accountName") > -1) {
            B++;
            /** @type {string} */
            length = length = "结算账户：" + scope.order.accountName;
            if ("ep-basic" == direction && B % 2 == 0) {
              ret += fn(e, length, "right", duration);
              ret += "\n";
              /** @type {string} */
              duration = "";
            } else {
              ret += length;
              ret += "ep-basic" != direction ? "\n" : "";
              /** @type {string} */
              duration = length;
            }
          }
          if ("\n" != ret.charAt(ret.length - 1)) {
            ret += "\n";
          }
          data.footer += ret;
        }
        if (scope.salePayTrade) {
          if ("success" == scope.salePayTrade.tradeStatus) {
            length = ("alipayBarPay" == scope.salePayTrade.payType ? "支付宝支付： " : "微信支付： ") + join("lbCurrency")(scope.salePayTrade.amount.toFixed(2), "￥");
            if ("ep-basic" == direction) {
              data.footer += length;
              duration = length;
              /** @type {string} */
              length = "商家订单号： " + scope.salePayTrade.tradeSn;
              data.footer += fn(e, length, "right", duration);
              data.footer += "\n";
            } else {
              data.footer += length + "\n";
              data.footer += "商家订单号： " + scope.salePayTrade.tradeSn + "\n";
            }
          }
        }
        /** @type {number} */
        var n = 0;
        db.post("/KEY041?clientId=" + scope.order.clientId).success(function(result) {
          if (!opts || obj.indexOf("clientBanlance") > -1) {
            if (result.banlance) {
              n = result.banlance;
            }
            /** @type {number} */
            var now = Math.abs(scope.order.trueTotalAmount.toFixed(2));
            if (scope.order.wipeZero) {
              now = self.accSub(now, scope.order.wipeZero);
            }
            if (scope.order.otherCost) {
              now = self.accAdd(now, scope.order.otherCost);
            }
            /** @type {string} */
            var str = "";
            if (null != scope.order.beforeBalance) {
              var newVelocity = path == ide.saleReturnOrder && scope.order.trueTotalAmount < 0 ? -now : now;
              newVelocity -= scope.order.alreadyPaid;
              /** @type {string} */
              var _ = "本单欠款：";
              if (path == ide.saleReturnOrder && newVelocity >= 0) {
                /** @type {string} */
                _ = "本单欠付：";
              } else {
                if (path == ide.saleReturnOrder) {
                  if (0 > newVelocity) {
                    /** @type {string} */
                    _ = "本单欠收：";
                  }
                }
              }
              _ += join("lbCurrency")(Math.abs(newVelocity).toFixed(2), collection.currencySymbol);
              var sec = path == ide.saleOrder ? scope.order.beforeBalance + newVelocity : scope.order.beforeBalance - newVelocity;
              var key = "累计欠款：" + join("lbCurrency")(sec.toFixed(2), collection.currencySymbol);
              /** @type {number} */
              var dist = 2;
              if ("ep-basic" != direction && ("110mm" != direction && "80mm" != direction) || (null == scope.order.beforeBalance || (str += "上次欠款：" + join("lbCurrency")(scope.order.beforeBalance.toFixed(2), collection.currencySymbol), dist = 3)), e - self.getBytesLength(str + _ + key) - dist >= 0) {
                /** @type {number} */
                var b = 0;
                /** @type {number} */
                var a = (e - self.getBytesLength(str + _ + key)) / dist;
                for (;a > b;b++) {
                  if (!("ep-basic" != direction && ("110mm" != direction && "80mm" != direction))) {
                    if (!(null == scope.order.beforeBalance)) {
                      str += " ";
                    }
                  }
                  _ += " ";
                }
                str += _;
                str += key;
              } else {
                if (("ep-basic" == direction || ("110mm" == direction || "80mm" == direction)) && null != scope.order.beforeBalance) {
                  /** @type {number} */
                  b = 0;
                  /** @type {number} */
                  a = (e - self.getBytesLength(str + _)) / 2;
                  for (;a > b;b++) {
                    str += " ";
                  }
                }
                str += _ + "\n";
                str += key;
              }
            } else {
              str = "本单欠款：" + join("lbCurrency")((now - Math.abs(scope.order.alreadyPaid)).toFixed(2), collection.currencySymbol);
            }
            data.total += str + "\n";
          }
          if (obj && obj.indexOf("clientScore") > -1) {
            var O = result.score ? result.score : 0;
            data.total += "客户积分：" + O + "\n";
          }
          if (!opts || obj.indexOf("remark") > -1) {
            if (scope.order.remark) {
              data.footer += "\n备注：" + scope.order.remark + "\n";
            }
          }
          if (!opts || obj.indexOf("printTime") > -1) {
            data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
          }
          if ("\n" != data.footer.charAt(ret.length - 1)) {
            data.footer += "\n";
          }
          data.footer += onload(e, opts, $P, boardState);
          dfrd.resolve(data);
        }).error(function() {
          if (!opts || obj.indexOf("remark") > -1) {
            if (scope.order.remark) {
              data.footer += "\n备注：" + scope.order.remark + "\n";
            }
          }
          if (!opts || obj.indexOf("printTime") > -1) {
            data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
          }
          data.footer += onload(e, opts, $P, boardState);
          dfrd.resolve(data);
        });
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        dfrd.reject();
      });
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} o
   * @param {string} args
   * @param {number} path
   * @return {?}
   */
  function exec(o, args, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + ide.retailOrder).success(function(w) {
      var arrayClass;
      var fragmentIdStr;
      var tr;
      var $P;
      var obj;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var opts = false;
      if (w.object) {
        if (arrayClass = w.object.printType ? w.object.printType : "goodsGroupPrint", fragmentIdStr = w.object.templateType, fragmentIdStr.indexOf("ep-basic") > -1) {
          var max = fragmentIdStr.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          fragmentIdStr = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        obj = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        opts = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = fragmentIdStr;
      } else {
        /** @type {string} */
        fragmentIdStr = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      /** @type {string} */
      var id = "";
      if (!opts || obj.indexOf("color") > -1) {
        id += "color,";
      }
      if (!opts || obj.indexOf("size") > -1) {
        id += "size";
      }
      db.post("/KEY461?ordersSn=" + args + "&enableColumns=" + id).success(function(scope) {
        if (null == scope.order) {
          return self.toastShow("找不到指定的数据"), dfrd.reject(), dfrd.promise;
        }
        /** @type {Array} */
        var $ul = [{
          name : "商品",
          sizeToSplit : 0.2
        }, {
          name : "数量",
          sizeToSplit : 0.4
        }, {
          name : "单价",
          sizeToSplit : 0.1
        }, {
          name : "金额",
          sizeToSplit : 0.1
        }];
        /** @type {boolean} */
        var boardState = true;
        if (opts) {
          if (fragmentIdStr) {
            if ("58mm" == fragmentIdStr) {
              /** @type {number} */
              e = 32;
              /** @type {Array} */
              $ul = [{
                name : "商品",
                sizeToSplit : 1 / 8
              }, {
                name : "数量",
                sizeToSplit : 1 / 8
              }, {
                name : "单价",
                sizeToSplit : 0.25
              }, {
                name : "金额",
                sizeToSplit : 0.25
              }];
              if (obj) {
                if (obj.indexOf("discount") > -1) {
                  /** @type {Array} */
                  $ul = [{
                    name : "商品",
                    sizeToSplit : 0.1
                  }, {
                    name : "数量",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "折扣%",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "折后价",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "金额",
                    sizeToSplit : 1 / 8
                  }];
                }
              }
            } else {
              if ("80mm" == fragmentIdStr) {
                /** @type {number} */
                e = 48;
              } else {
                if ("110mm" == fragmentIdStr) {
                  /** @type {number} */
                  e = 68;
                  /** @type {boolean} */
                  boardState = false;
                } else {
                  if ("ep-basic" == fragmentIdStr) {
                    /** @type {number} */
                    e = 100;
                    /** @type {boolean} */
                    boardState = false;
                    /** @type {Array} */
                    $ul = [{
                      name : "商品",
                      sizeToSplit : 0.25
                    }, {
                      name : "数量",
                      sizeToSplit : 3 / 8
                    }, {
                      name : "单价",
                      sizeToSplit : 1 / 8
                    }, {
                      name : "金额",
                      sizeToSplit : 1 / 8
                    }];
                  }
                }
              }
            }
          }
        }
        var data = {
          title : "\n",
          content : "\n",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : fragmentIdStr
        };
        if (max) {
          data.pageSize = max;
        }
        var contents = JSpec.localStorage.PrintQRCode;
        if (contents) {
          data.qrCode = angular.fromJson(contents);
        }
        if ("ep-basic" == data.printTpl) {
          data.title += $(e / 2, o, "center");
          data.title += $(e / 2, "零售单", "center");
        } else {
          data.title += o + "\n";
          data.title += "零售单\n";
        }
        if (opts) {
          if (tr) {
            data.content += $(e, tr);
            data.content += "\n";
          }
        }
        /** @type {number} */
        var O = 0;
        /** @type {string} */
        var length = "";
        /** @type {string} */
        var ret = "";
        /** @type {string} */
        var duration = "";
        if (!opts || obj.indexOf("depotName") > -1) {
          O++;
          /** @type {string} */
          length = "仓库：" + scope.order.depotName;
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("handlerName") > -1) {
          O++;
          /** @type {string} */
          length = "收银员：" + scope.order.handlerName;
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("salerName") > -1) {
          O++;
          /** @type {string} */
          length = "销售员：" + scope.order.salerName;
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("ordersSn") > -1) {
          O++;
          /** @type {string} */
          length = "单号：" + scope.order.ordersSn;
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if (!opts || obj.indexOf("createTime") > -1) {
          O++;
          length = "时间：" + join("date")(scope.order.createTime, "yyyy-MM-dd HH:mm:ss");
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
          }
        }
        if ("\n" != ret.charAt(ret.length - 1)) {
          ret += "\n";
        }
        data.content += ret;
        data.content += cb(e);
        /** @type {boolean} */
        var goodsGroupPrint = "goodsGroupPrint" == arrayClass;
        /** @type {boolean} */
        var isArr = "sizeHorizonPrint" == arrayClass;
        if (isArr) {
          var result = bind(scope, e, opts, obj, $ul, boardState, path);
          data.content += result.goodsDetail;
          data.total += result.total;
        } else {
          if (goodsGroupPrint) {
            result = start(scope, e, opts, obj, $ul, boardState, path);
            data.content += result.goodsDetail;
            data.total += result.total;
          } else {
            result = render(scope, e, opts, obj, $ul, boardState, path);
            data.content += result.goodsDetail;
            data.total += result.total;
          }
        }
        data.footer += cb(e);
        /** @type {number} */
        O = 0;
        /** @type {string} */
        length = "";
        /** @type {string} */
        ret = "";
        /** @type {string} */
        duration = "";
        if (!opts || obj.indexOf("trueTotalAmount") > -1) {
          O++;
          length = "收款金额： " + join("lbCurrency")(scope.order.trueTotalAmount.toFixed(2), collection.currencySymbol);
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            duration = length;
          }
        }
        if (!opts || obj.indexOf("wipeZero") > -1) {
          O++;
          length = "抹零金额： " + join("lbCurrency")(scope.order.wipeZero.toFixed(2), collection.currencySymbol);
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            duration = length;
          }
        }
        if (!opts || obj.indexOf("changeAmount") > -1) {
          O++;
          length = "找零金额： " + join("lbCurrency")(parseFloat(self.accSub(scope.order.trueTotalAmount, self.accSub(scope.order.totalAmount, scope.order.wipeZero ? scope.order.wipeZero : 0))).toFixed(2), collection.currencySymbol);
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            duration = length;
          }
        }
        if (!opts || obj.indexOf("accountName") > -1) {
          O++;
          /** @type {string} */
          length = "结算账户：" + scope.order.accountName;
          if ("ep-basic" == fragmentIdStr && O % 2 == 0) {
            ret += fn(e, length, "right", duration);
            ret += "\n";
            /** @type {string} */
            duration = "";
          } else {
            ret += length;
            ret += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            duration = length;
          }
        }
        if ("\n" != ret.charAt(ret.length - 1)) {
          ret += "\n";
        }
        data.footer += ret;
        if (scope.salePayTrade) {
          if ("success" == scope.salePayTrade.tradeStatus) {
            length = ("alipayBarPay" == scope.salePayTrade.payType ? "支付宝支付： " : "微信支付： ") + join("lbCurrency")(scope.salePayTrade.amount.toFixed(2), "￥");
            if ("ep-basic" == fragmentIdStr) {
              data.footer += length;
              duration = length;
              /** @type {string} */
              length = "商家订单号： " + scope.salePayTrade.tradeSn;
              data.footer += fn(e, length, "right", duration);
              data.footer += "\n";
            } else {
              data.footer += length + "\n";
              data.footer += "商家订单号： " + scope.salePayTrade.tradeSn + "\n";
            }
          }
        }
        if (!opts || obj.indexOf("printTime") > -1) {
          data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
        }
        data.footer += onload(e, opts, $P, boardState);
        dfrd.resolve(data);
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        dfrd.reject();
      });
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} o
   * @param {string} element
   * @param {number} path
   * @return {?}
   */
  function compile(o, element, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      var arrayClass;
      var fragmentIdStr;
      var tr;
      var $P;
      var target;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var opts = false;
      if (w.object) {
        if (arrayClass = w.object.printType ? w.object.printType : "goodsGroupPrint", fragmentIdStr = w.object.templateType, fragmentIdStr.indexOf("ep-basic") > -1) {
          var max = fragmentIdStr.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          fragmentIdStr = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        target = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        opts = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = fragmentIdStr;
      } else {
        /** @type {string} */
        fragmentIdStr = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      /** @type {string} */
      var id = "";
      if (!opts || target.indexOf("color") > -1) {
        id += "color,";
      }
      if (!opts || target.indexOf("size") > -1) {
        id += "size";
      }
      /** @type {string} */
      var optsData = "";
      switch(path) {
        case ide.KEY329:
          /** @type {string} */
          optsData = "/KEY457?purchaseSn=";
          break;
        case ide.KEY330:
          /** @type {string} */
          optsData = "/KEY458?purchaseSn=";
      }
      db.post(optsData + element + "&enableColumns=" + id).success(function(scope) {
        if (null == scope.order) {
          return self.toastShow("找不到指定的数据"), dfrd.reject(), dfrd.promise;
        }
        /** @type {Array} */
        var $ul = [{
          name : "商品",
          sizeToSplit : 0.2
        }, {
          name : "数量",
          sizeToSplit : 0.4
        }, {
          name : "单价",
          sizeToSplit : 0.1
        }, {
          name : "金额",
          sizeToSplit : 0.1
        }];
        if (target) {
          if (target.indexOf("discount") > -1) {
            /** @type {Array} */
            $ul = [{
              name : "商品",
              sizeToSplit : 0.1
            }, {
              name : "数量",
              sizeToSplit : 0.4
            }, {
              name : "折扣%",
              sizeToSplit : 0.1
            }, {
              name : "折后价",
              sizeToSplit : 0.1
            }, {
              name : "金额",
              sizeToSplit : 0.1
            }];
          }
        }
        /** @type {boolean} */
        var boardState = true;
        if (opts) {
          if (fragmentIdStr) {
            if ("58mm" == fragmentIdStr) {
              /** @type {number} */
              e = 32;
              /** @type {Array} */
              $ul = [{
                name : "商品",
                sizeToSplit : 1 / 8
              }, {
                name : "数量",
                sizeToSplit : 1 / 8
              }, {
                name : "单价",
                sizeToSplit : 0.25
              }, {
                name : "金额",
                sizeToSplit : 0.25
              }];
              if (target) {
                if (target.indexOf("discount") > -1) {
                  /** @type {Array} */
                  $ul = [{
                    name : "商品",
                    sizeToSplit : 0.1
                  }, {
                    name : "数量",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "折扣%",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "折后价",
                    sizeToSplit : 1 / 8
                  }, {
                    name : "金额",
                    sizeToSplit : 1 / 8
                  }];
                }
              }
            } else {
              if ("80mm" == fragmentIdStr) {
                /** @type {number} */
                e = 48;
              } else {
                if ("110mm" == fragmentIdStr) {
                  /** @type {number} */
                  e = 68;
                  /** @type {boolean} */
                  boardState = false;
                } else {
                  if ("ep-basic" == fragmentIdStr) {
                    /** @type {number} */
                    e = 100;
                    /** @type {boolean} */
                    boardState = false;
                    /** @type {Array} */
                    $ul = [{
                      name : "商品",
                      sizeToSplit : 0.25
                    }, {
                      name : "数量",
                      sizeToSplit : 3 / 8
                    }, {
                      name : "折扣%",
                      sizeToSplit : 1 / 8
                    }, {
                      name : "单价",
                      sizeToSplit : 0.5 / 8
                    }, {
                      name : "金额",
                      sizeToSplit : 1 / 8
                    }];
                    if (target) {
                      if (target.indexOf("discount") > -1) {
                        /** @type {string} */
                        $ul[3].name = "折后价";
                      }
                    }
                  }
                }
              }
            }
          }
        }
        var data = {
          title : "",
          content : "\n",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : fragmentIdStr
        };
        if (max) {
          data.pageSize = max;
        }
        var contents = JSpec.localStorage.PrintQRCode;
        if (contents) {
          data.qrCode = angular.fromJson(contents);
        }
        if ("ep-basic" == data.printTpl) {
          data.title += $(e / 2, o, "center");
          data.title += path === ide.KEY329 ? $(e / 2, "进货单", "center") : $(e / 2, "进货退货单", "center");
        } else {
          data.title += o + "\n";
          data.title += path === ide.KEY329 ? "进货单\n" : "进货退货单\n";
        }
        if (opts) {
          if (tr) {
            data.content += $(e, tr);
            data.content += "\n";
          }
        }
        /** @type {number} */
        var cnt = 0;
        /** @type {string} */
        var index = "";
        /** @type {string} */
        var result = "";
        /** @type {string} */
        var val = "";
        if (!opts || target.indexOf("ordersSn") > -1) {
          cnt++;
          /** @type {string} */
          index = "单号：" + scope.order.purchaseSn;
          if ("ep-basic" == fragmentIdStr && cnt % 2 == 0) {
            result += fn(e, index, "right", val);
            result += "\n";
            /** @type {string} */
            val = "";
          } else {
            result += index;
            result += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            val = index;
          }
        }
        if (!opts || target.indexOf("handlerName") > -1) {
          cnt++;
          /** @type {string} */
          index = "制单人：" + scope.order.handlerName;
          if ("ep-basic" == fragmentIdStr && cnt % 2 == 0) {
            result += fn(e, index, "right", val);
            result += "\n";
            /** @type {string} */
            val = "";
          } else {
            result += index;
            result += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            val = index;
          }
        }
        if (!opts || target.indexOf("updateTime") > -1) {
          cnt++;
          index = "业务日期：" + join("date")(scope.order.businessTime, "yyyy-MM-dd HH:mm:ss");
          if ("ep-basic" == fragmentIdStr && cnt % 2 == 0) {
            result += fn(e, index, "right", val);
            result += "\n";
            /** @type {string} */
            val = "";
          } else {
            result += index;
            result += "ep-basic" != fragmentIdStr ? "\n" : "";
            val = index;
          }
        }
        if (!opts || target.indexOf("depotName") > -1) {
          cnt++;
          /** @type {string} */
          index = "仓库：" + scope.order.depotName;
          if ("ep-basic" == fragmentIdStr && cnt % 2 == 0) {
            result += fn(e, index, "right", val);
            result += "\n";
            /** @type {string} */
            val = "";
          } else {
            result += index;
            result += "ep-basic" != fragmentIdStr ? "\n" : "";
            /** @type {string} */
            val = index;
          }
        }
        if (!opts || target.indexOf("supplierName") > -1) {
          cnt++;
          /** @type {string} */
          index = "供应商：" + scope.order.supplierName;
          if ("ep-basic" == fragmentIdStr && cnt % 2 == 0) {
            result += fn(e, index, "right", val);
            result += "\n";
          } else {
            result += index;
            result += "ep-basic" != fragmentIdStr ? "\n" : "";
          }
        }
        if ("\n" != result.charAt(result.length - 1)) {
          result += "\n";
        }
        data.content += result;
        data.content += cb(e);
        /** @type {boolean} */
        var goodsGroupPrint = "goodsGroupPrint" == arrayClass;
        /** @type {boolean} */
        var isArr = "sizeHorizonPrint" == arrayClass;
        if (isArr) {
          var ret = bind(scope, e, opts, target, $ul, boardState, path);
          data.content += ret.goodsDetail;
          data.total += ret.total;
        } else {
          if (goodsGroupPrint) {
            ret = start(scope, e, opts, target, $ul, boardState, path);
            data.content += ret.goodsDetail;
            data.total += ret.total;
          } else {
            ret = render(scope, e, opts, target, $ul, boardState, path);
            data.content += ret.goodsDetail;
            data.total += ret.total;
          }
        }
        if (data.footer += cb(e), cnt = 0, index = "", result = "", val = "", scope.order.wipeZero && (cnt++, index = "抹零金额： " + join("lbCurrency")(scope.order.wipeZero.toFixed(2), collection.currencySymbol), "ep-basic" == fragmentIdStr && cnt % 2 == 0 ? (result += fn(e, index, "right", val), result += "\n", val =
        "") : (result += index, result += "ep-basic" != fragmentIdStr ? "\n" : "", val = index)), scope.order.otherCost && (cnt++, index = "其他费用： " + scope.order.otherAccountItemName + "  " + join("lbCurrency")(scope.order.otherCost.toFixed(2), collection.currencySymbol), "ep-basic" == fragmentIdStr && cnt % 2 == 0 ? (result += fn(e, index, "right", val),
        result += "\n", val = "") : (result += index, result += "ep-basic" != fragmentIdStr ? "\n" : "", val = index)), (!opts || target.indexOf("alreadyPaid") > -1) && (cnt++, index = (path === ide.KEY329 ? "实付金额： " : "实收金额： ") + join("lbCurrency")(scope.order.alreadyPaid.toFixed(2), collection.currencySymbol), "ep-basic" == fragmentIdStr &&
        cnt % 2 == 0 ? (result += fn(e, index, "right", val), result += "\n", val = "") : (result += index, result += "ep-basic" != fragmentIdStr ? "\n" : "", val = index)), (!opts || target.indexOf("accountName") > -1) && (cnt++, index = "结算账户：" + scope.order.accountName, "ep-basic" == fragmentIdStr && cnt % 2 == 0 ? (result +=
        fn(e, index, "right", val), result += "\n", val = "") : (result += index, result += "ep-basic" != fragmentIdStr ? "\n" : "", val = index)), "\n" != result.charAt(result.length - 1) && (result += "\n"), data.content += result, !opts || target.indexOf("supplierBanlance") > -1) {
          /** @type {number} */
          var l = 0;
          db.post("/KEY015?supplierId=" + scope.order.supplierId).success(function(models) {
            if (models.banlance) {
              l = models.banlance;
            }
            data.footer += "欠供应商款： " + join("lbCurrency")(l.toFixed(2), collection.currencySymbol) + "\n";
            if (!opts || target.indexOf("remark") > -1) {
              if (scope.order.remark) {
                data.footer += "\n备注：" + scope.order.remark + "\n";
              }
            }
            if (!opts || target.indexOf("printTime") > -1) {
              data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
            }
            data.footer += onload(e, opts, $P, boardState);
            dfrd.resolve(data);
          });
        } else {
          if (!opts || target.indexOf("remark") > -1) {
            if (scope.order.remark) {
              data.footer += "\n备注：" + scope.order.remark + "\n";
            }
          }
          if (!opts || target.indexOf("printTime") > -1) {
            data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
          }
          data.footer += onload(e, opts, $P, boardState);
          dfrd.resolve(data);
        }
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        dfrd.reject();
      });
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} opt_key
   * @param {string} req
   * @param {string} path
   * @return {?}
   */
  function get(opt_key, req, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      var arrayClass;
      var fragmentIdStr;
      var tr;
      var $P;
      var value;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var resolved = false;
      if (w.object) {
        if (arrayClass = w.object.printType ? w.object.printType : "goodsGroupPrint", fragmentIdStr = w.object.templateType, fragmentIdStr.indexOf("ep-basic") > -1) {
          var max = fragmentIdStr.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          fragmentIdStr = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        value = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        resolved = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = fragmentIdStr;
      } else {
        /** @type {string} */
        fragmentIdStr = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      /** @type {string} */
      var id = "";
      if (!resolved || value.indexOf("color") > -1) {
        id += "color,";
      }
      if (!resolved || value.indexOf("size") > -1) {
        id += "size";
      }
      db.post("/KEY462?orderNo=" + req + "&enableColumns=" + id).success(function(query) {
        if (null == query.order) {
          return self.toastShow("找不到指定的数据"), dfrd.reject(), dfrd.promise;
        }
        /** @type {Array} */
        var maxWidth = [{
          name : "商品",
          sizeToSplit : 0.25
        }, {
          name : "调出库当前数",
          sizeToSplit : 0.25
        }, {
          name : "调入库当前数",
          sizeToSplit : 0.25
        }, {
          name : "调拨数量",
          sizeToSplit : 0.25
        }];
        /** @type {boolean} */
        var r20 = true;
        if (resolved) {
          if (fragmentIdStr) {
            if ("58mm" == fragmentIdStr) {
              /** @type {number} */
              e = 32;
              /** @type {Array} */
              maxWidth = [{
                name : "商品",
                sizeToSplit : 0.25
              }, {
                name : "调出当前",
                sizeToSplit : 0.25
              }, {
                name : "调入当前",
                sizeToSplit : 0.25
              }, {
                name : "数量",
                sizeToSplit : 0.25
              }];
            } else {
              if ("80mm" == fragmentIdStr) {
                /** @type {number} */
                e = 48;
              } else {
                if ("110mm" == fragmentIdStr) {
                  /** @type {number} */
                  e = 68;
                } else {
                  if ("ep-basic" == fragmentIdStr) {
                    /** @type {number} */
                    e = 100;
                    /** @type {boolean} */
                    r20 = false;
                    /** @type {Array} */
                    maxWidth = [{
                      name : "商品",
                      sizeToSplit : 0.25
                    }, {
                      name : "调出库当前数",
                      sizeToSplit : 0.5
                    }, {
                      name : "调入库当前数",
                      sizeToSplit : 1 / 8
                    }, {
                      name : "调拨数量",
                      sizeToSplit : 1 / 8
                    }];
                  }
                }
              }
            }
          }
        }
        var data = {
          title : "\n",
          content : "\n",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : fragmentIdStr
        };
        if (max) {
          data.pageSize = max;
        }
        if ("ep-basic" == data.printTpl) {
          data.title += $(e / 2, opt_key, "center");
          data.title += $(e / 2, "库存调拨单", "center");
        } else {
          data.title += opt_key + "\n";
          data.title += "库存调拨单\n";
        }
        if (resolved) {
          if (tr) {
            data.content += $(e, tr);
            data.content += "\n";
          }
        }
        if (!resolved || value.indexOf("ordersSn") > -1) {
          data.content += "单号：" + query.order.orderNo + "\n";
        }
        if (!resolved || value.indexOf("submitUserName") > -1) {
          data.content += "制单人：" + query.order.submitUserName + "\n";
        }
        if (!resolved || value.indexOf("updateTime") > -1) {
          data.content += "业务日期：" + join("date")(query.order.updateTime, "yyyy-MM-dd HH:mm:ss") + "\n";
        }
        if (!resolved || value.indexOf("depotNameOut") > -1) {
          data.content += "调出仓库：" + query.order.outStorehouseName + "\n";
        }
        if (!resolved || value.indexOf("depotNameIn") > -1) {
          data.content += "调入仓库：" + query.order.inStorehouseName + "\n";
        }
        data.content += cb(e);
        /** @type {boolean} */
        var isArr = "goodsGroupPrint" == arrayClass;
        if (isArr) {
          var info = validate(query, e, resolved, value, maxWidth, r20, path);
          data.content += info.goodsDetail;
          data.total += info.total;
        } else {
          info = toString(query, e, resolved, value, maxWidth, r20, path);
          data.content += info.goodsDetail;
          data.total += info.total;
        }
        data.footer += cb(e);
        if (!resolved || value.indexOf("remark") > -1) {
          if (query.order.remark) {
            data.footer += "\n备注：" + query.order.remark + "\n";
          }
        }
        if (!resolved || value.indexOf("printTime") > -1) {
          data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
        }
        data.footer += onload(e, resolved, $P, r20);
        dfrd.resolve(data);
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        dfrd.reject();
      });
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} elem
   * @param {string} id
   * @param {string} path
   * @return {?}
   */
  function request(elem, id, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      var fragmentIdStr;
      var tr;
      var $P;
      var $location;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var oldtitle = false;
      if (w.object) {
        if (fragmentIdStr = w.object.templateType, fragmentIdStr.indexOf("ep-basic") > -1) {
          var max = fragmentIdStr.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          fragmentIdStr = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        $location = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        oldtitle = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = fragmentIdStr;
      } else {
        /** @type {string} */
        fragmentIdStr = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      db.post("/admin/inner/finance/banlance/record/clientRecordPrint.ac?businessSn=" + id).success(function($scope) {
        if (null == $scope.object) {
          return self.toastShow("没有数据"), dfrd.reject(), dfrd.promise;
        }
        /** @type {boolean} */
        var r20 = true;
        if (oldtitle) {
          if (fragmentIdStr) {
            if ("58mm" == fragmentIdStr) {
              /** @type {number} */
              e = 32;
            } else {
              if ("80mm" == fragmentIdStr) {
                /** @type {number} */
                e = 48;
              } else {
                if ("110mm" == fragmentIdStr) {
                  /** @type {number} */
                  e = 68;
                } else {
                  if ("ep-basic" == fragmentIdStr) {
                    /** @type {number} */
                    e = 100;
                    /** @type {boolean} */
                    r20 = false;
                  }
                }
              }
            }
          }
        }
        var data = {
          title : "\n",
          content : "\n",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : fragmentIdStr
        };
        if (max) {
          data.pageSize = max;
        }
        var contents = JSpec.localStorage.PrintQRCode;
        if (contents && (data.qrCode = angular.fromJson(contents)), "ep-basic" == data.printTpl ? (data.title += $(e / 2, elem, "center"), path === ide.receiptOrder && (data.title += $(e / 2, "收款单", "center"))) : (data.title += elem + "\n", path === ide.receiptOrder && (data.title += "收款单\n")), oldtitle && (tr &&
        (data.content += $(e, tr), data.content += "\n")), (!oldtitle || $location.indexOf("businessSn") > -1) && (data.content += "单号：" + $scope.object.businessSn + "\n"), !oldtitle || $location.indexOf("handlerName") > -1) {
          var failureMessage = $scope.object.handlerName ? $scope.object.handlerName : "";
          data.content += "经手人：" + failureMessage + "\n";
        }
        if ((!oldtitle || $location.indexOf("businessTime") > -1) && (data.content += "业务日期：" + join("date")($scope.object.businessTime, "yyyy-MM-dd HH:mm:ss") + "\n"), (!oldtitle || $location.indexOf("clientName") > -1) && (data.content += "客户：" + $scope.object.clientName + "\n"), !oldtitle || $location.indexOf("clientCellPhone") > -1) {
          var nameSuffix = $scope.object.clientCellPhone ? $scope.object.clientCellPhone : "";
          data.content += "客户手机：" + nameSuffix + "\n";
        }
        if (!oldtitle || $location.indexOf("clientPhone") > -1) {
          var pauseText = $scope.object.clientPhone ? $scope.object.clientPhone : "";
          data.content += "客户电话：" + pauseText + "\n";
        }
        if (!oldtitle || $location.indexOf("clientAddress") > -1) {
          var authParam = $scope.object.clientAddress ? $scope.object.clientAddress : "";
          data.content += "客户地址：" + authParam + "\n";
        }
        if ((!oldtitle || $location.indexOf("accountItem") > -1) && (data.footer += "收款类型：" + $scope.object.accountItem + "\n"), !oldtitle || $location.indexOf("KEY293") > -1) {
          var playText = $scope.object.KEY293 ? $scope.object.KEY293 : "";
          data.footer += "结算账户：" + playText + "\n";
        }
        if ((!oldtitle || $location.indexOf("balance") > -1) && (data.footer += "上次欠款： " + join("lbCurrency")($scope.object.beforeBalance.toFixed(2), collection.currencySymbol) + "\n"), (!oldtitle || $location.indexOf("realAmount") > -1) && (data.footer += "收款金额： " + join("lbCurrency")($scope.object.realAmount, collection.currencySymbol) + "\n"), $scope.object.needAmount < 0 && ((!oldtitle ||
        $location.indexOf("realAmount") > -1) && (data.footer += "优惠金额： " + join("lbCurrency")(-$scope.object.needAmount, collection.currencySymbol) + "\n")), !oldtitle || $location.indexOf("balance") > -1) {
          var sec = $scope.object.beforeBalance - $scope.object.realAmount + $scope.object.needAmount;
          data.footer += "累计欠款： " + join("lbCurrency")(sec.toFixed(2), collection.currencySymbol) + "\n";
        }
        if (!oldtitle || $location.indexOf("balance") > -1) {
          data.footer += "总欠款： " + join("lbCurrency")($scope.object.banlance.toFixed(2), collection.currencySymbol) + "\n";
        }
        if (!oldtitle || $location.indexOf("remark") > -1) {
          if ($scope.object.remark) {
            data.footer += "\n备注：" + $scope.object.remark + "\n";
          }
        }
        if (!oldtitle || $location.indexOf("printTime") > -1) {
          data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
        }
        data.footer += onload(e, oldtitle, $P, r20);
        dfrd.resolve(data);
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        dfrd.reject();
      });
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} name
   * @param {Object} item
   * @param {string} path
   * @return {?}
   */
  function load(name, item, path) {
    var dfrd = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      var fragmentIdStr;
      var tr;
      var $P;
      var thing;
      var e = collection.printLineByteSize;
      /** @type {boolean} */
      var oldtitle = false;
      if (w.object) {
        if (fragmentIdStr = w.object.templateType, fragmentIdStr.indexOf("ep-basic") > -1) {
          var max = fragmentIdStr.substr(9);
          max = max ? max : "halving";
          /** @type {string} */
          fragmentIdStr = "ep-basic";
        }
        tr = w.object.headerText;
        $P = w.object.footerText;
        thing = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        oldtitle = true;
        JSpec.localStorage["PrintTimes" + path] = w.object.printTimes ? w.object.printTimes : 1;
        JSpec.localStorage["PrintSize" + path] = fragmentIdStr;
      } else {
        /** @type {string} */
        fragmentIdStr = "80mm";
        /** @type {number} */
        JSpec.localStorage["PrintTimes" + path] = 1;
        /** @type {string} */
        JSpec.localStorage["PrintSize" + path] = "80mm";
      }
      if (null == item) {
        return self.toastShow("没有数据"), dfrd.reject(), dfrd.promise;
      }
      /** @type {boolean} */
      var r20 = true;
      if (oldtitle) {
        if (fragmentIdStr) {
          if ("58mm" == fragmentIdStr) {
            /** @type {number} */
            e = 32;
          } else {
            if ("80mm" == fragmentIdStr) {
              /** @type {number} */
              e = 48;
            } else {
              if ("110mm" == fragmentIdStr) {
                /** @type {number} */
                e = 68;
              } else {
                if ("ep-basic" == fragmentIdStr) {
                  /** @type {number} */
                  e = 100;
                  /** @type {boolean} */
                  r20 = false;
                }
              }
            }
          }
        }
      }
      var data = {
        title : "\n",
        content : "\n",
        total : "",
        footer : "",
        qrCode : {
          text : "",
          slogan : "",
          enable : false
        },
        printTpl : fragmentIdStr
      };
      if (max) {
        data.pageSize = max;
      }
      var contents = JSpec.localStorage.PrintQRCode;
      if (contents) {
        data.qrCode = angular.fromJson(contents);
      }
      if ("ep-basic" == data.printTpl) {
        data.title += $(e / 2, name, "center");
        if (path === ide.fastReceiptOrder) {
          data.title += $(e / 2, "收款单", "center");
        }
      } else {
        data.title += name + "\n";
        if (path === ide.fastReceiptOrder) {
          data.title += "收款单\n";
        }
      }
      if (oldtitle) {
        if (tr) {
          data.content += $(e, tr);
          data.content += "\n";
        }
      }
      if (item.clientName) {
        if (!oldtitle || thing.indexOf("clientName") > -1) {
          data.content += "客户：" + item.clientName + "\n";
        }
      }
      if (!oldtitle || thing.indexOf("accountName") > -1) {
        data.content += "结算账户：" + item.accountName + "\n";
      }
      if (!oldtitle || thing.indexOf("accountItemName") > -1) {
        data.content += "账目类型：" + item.accountItemName + "\n";
      }
      if (!oldtitle || thing.indexOf("receiptSn") > -1) {
        data.content += "单号：" + item.receiptSn + "\n";
      }
      if (!oldtitle || thing.indexOf("createTime") > -1) {
        data.content += "业务日期：" + join("date")(item.createTime, "yyyy-MM-dd HH:mm:ss") + "\n";
      }
      if (!oldtitle || thing.indexOf("amount") > -1) {
        data.total += "\n收款金额： " + join("lbCurrency")(item.amount.toFixed(2), collection.currencySymbol) + "\n";
      }
      if (!oldtitle || thing.indexOf("payType") > -1) {
        if ("cash" == item.payType) {
          data.total += "收款方式： 现金\n";
        } else {
          if ("alipayBarPay" == item.payType) {
            data.total += "收款方式： 支付宝扫码\n";
          } else {
            if ("wxpayScanPay" == item.payType) {
              data.total += "收款方式： 微信扫码\n";
            }
          }
        }
      }
      if (!oldtitle || thing.indexOf("remark") > -1) {
        if (item.remark) {
          data.footer += "\n备注：" + item.remark + "\n";
        }
      }
      if (!oldtitle || thing.indexOf("printTime") > -1) {
        data.footer += "\n" + $(e, "打印时间：" + join("date")(new Date, "yyyy-MM-dd HH:mm:ss"));
      }
      data.footer += onload(e, oldtitle, $P, r20);
      dfrd.resolve(data);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      dfrd.reject();
    }), dfrd.promise;
  }
  /**
   * @param {string} keepData
   * @param {string} data
   * @return {?}
   */
  function process(keepData, data) {
    var defer = $q.defer();
    return self.isArray(data) ? db.post("/KEY331", data, {
      headers : {
        "Content-Type" : "application/json; charset=UTF-8"
      }
    }).success(function(res) {
      if (1 == res.statusCode) {
        /** @type {Array} */
        var app = [];
        /** @type {number} */
        var i = 0;
        for (;i < res.object.length;i++) {
          var row = res.object[i];
          var article = {
            title : "",
            content : "",
            total : "",
            footer : "",
            qrCode : {
              text : "",
              slogan : "",
              enable : false
            },
            printTpl : "110mm"
          };
          if (row) {
            if (row.printTemplate) {
              article.content = row.printTemplate;
            }
          }
          app.push(article);
        }
        defer.resolve(app);
      } else {
        console.error("服务器获取数据出现异常！");
        defer.reject();
      }
    }) : db.post("/admin/inner/delivery/orderonline/getByCourierNo.ac?courierNo=" + data).success(function(response) {
      if (1 == response.statusCode) {
        /** @type {Array} */
        var res = [];
        var article = {
          title : "",
          content : "",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : "110mm"
        };
        if (response.object) {
          if (response.object.printTemplate) {
            article.content = response.object.printTemplate;
          }
        }
        res.push(article);
        defer.resolve(res);
      } else {
        console.error("服务器获取数据出现异常！");
        defer.reject();
      }
    }), defer.promise;
  }
  /**
   * @param {Object} config
   * @param {string} name
   * @param {string} path
   * @return {?}
   */
  function read(config, name, path) {
    var result = $q.defer();
    return db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(w) {
      /** @type {number} */
      JSpec.localStorage["PrintTimes" + path] = 1;
      /** @type {string} */
      JSpec.localStorage["PrintSize" + path] = "ep-basic";
      var options;
      var failuresLink;
      var suiteView;
      var fmt;
      /** @type {boolean} */
      var p = false;
      var senderPhoneX = {
        senderNameX : 3,
        senderNameY : 5,
        senderNameW : 25,
        senderAddressX : 3,
        senderAddressY : 7,
        senderAddressW : 35,
        senderPhoneX : 3,
        senderPhoneY : 12,
        senderPhoneW : 12,
        receiverNameX : 53,
        receiverNameY : 5,
        receiverNameW : 25,
        receiverAddressX : 53,
        receiverAddressY : 7,
        receiverAddressW : 35,
        receiverPhoneX : 53,
        receiverPhoneY : 12,
        receiverPhoneW : 12,
        remarkX : 2,
        remarkY : 14,
        remarkW : 18
      };
      if (w.object) {
        try {
          /** @type {*} */
          options = w.object.headerText ? JSON.parse(w.object.headerText) : {};
        } catch (m) {
          options = {};
        }
        try {
          /** @type {*} */
          failuresLink = w.object.footerText ? JSON.parse(w.object.footerText) : senderPhoneX;
        } catch (m) {
          failuresLink = senderPhoneX;
        }
        suiteView = w.object.printType;
        fmt = w.object.selectColumnNames.split(",");
        /** @type {boolean} */
        p = true;
        if (w.object.printTimes) {
          JSpec.localStorage["PrintTimes" + path] = w.object.printTimes;
        }
      } else {
        options = {};
        failuresLink = senderPhoneX;
      }
      if (self.isArray(name)) {
        db.postArrParamEncode("/KEY402", {
          ordersns : name
        }).success(function(post) {
          /**
           * @return {?}
           */
          function fetch() {
            var imageDfd = $q.defer();
            var request1 = db.httpCacheGet.get(db.httpCacheGet.ac.AllArea);
            return $q.all([request1]).then(function(image) {
              imageDfd.resolve(image);
            }, function() {
              imageDfd.reject();
            }), imageDfd.promise;
          }
          if (null == post || !(post.object.length > 0)) {
            return self.toastShow("没有数据"), result.reject(), result.promise;
          }
          var codeSegments = post.object;
          /** @type {Array} */
          var res = [];
          /** @type {Array} */
          var key = [];
          fetch().then(function(packs) {
            /** @type {number} */
            var i = 0;
            for (;i < codeSegments.length;i++) {
              var article = {
                title : "\n",
                content : "",
                total : "",
                footer : "",
                qrCode : {
                  text : "",
                  slogan : "",
                  enable : false
                },
                printTpl : "ep-basic"
              };
              /** @type {string} */
              var data = "";
              /** @type {string} */
              var url = "";
              /** @type {string} */
              var requestUrl = "";
              if (options.name) {
                data = options.name;
              } else {
                if (config.comName) {
                  data = config.comName;
                }
              }
              if (data) {
                if (data.length > 0) {
                  /** @type {string} */
                  data = data.replace(/[\r\n]/g, "");
                }
              }
              if (options.address) {
                url = options.address;
              } else {
                if (config.address) {
                  url = config.address;
                }
              }
              if (url) {
                if (url.length > 0) {
                  /** @type {string} */
                  url = url.replace(/[\r\n]/g, "");
                }
              }
              if (options.phone) {
                requestUrl = options.phone;
              } else {
                if (config.phone) {
                  requestUrl = config.phone;
                }
              }
              if (requestUrl) {
                if (requestUrl.length > 0) {
                  /** @type {string} */
                  requestUrl = requestUrl.replace(/[\r\n]/g, "");
                }
              }
              /** @type {string} */
              var comment = "";
              /** @type {string} */
              var part = "";
              /** @type {string} */
              var rest = "";
              if (comment = codeSegments[i].objClient.clientName ? codeSegments[i].objClient.clientName : "", comment && (comment.length > 0 && (comment = comment.replace(/[\r\n]/g, ""))), rest = codeSegments[i].objClient.cellphone ? codeSegments[i].objClient.cellphone : "", rest && (rest.length > 0 && (rest = rest.replace(/[\r\n]/g, ""))), fmt && fmt.indexOf("remark") >
              -1) {
                var failureMessage = codeSegments[i].orderRemark ? codeSegments[i].orderRemark : ""
              }
              if (codeSegments[i].orderDelivery && (4 == codeSegments[i].orderDelivery.deliveryType && codeSegments[i].orderDelivery.toPoint)) {
                part = codeSegments[i].orderDelivery.toPoint;
                if (part) {
                  if (part.length > 0) {
                    part = part.replace(/[\r\n]/g, "");
                  }
                }
                article.content += find(suiteView, data, requestUrl, url, comment, rest, part, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
                res.push(article);
              } else {
                if (codeSegments[i].objClient.clientName) {
                  key = packs[0].data;
                  var value = self.getObjectList(key, "pid", 0);
                  /** @type {string} */
                  var str = "";
                  var that = {};
                  var rec = codeSegments[i].objClient;
                  if (rec.provinceId && (that.province = self.fnCheckGtoreQty(value, "id", rec.provinceId), str += that.province && that.province.areaName ? that.province.areaName : "", rec.cityId)) {
                    var node = self.getObjectList(key, "pid", that.province.id);
                    if (that.city = self.fnCheckGtoreQty(node, "id", rec.cityId), str += that.city && that.city.areaName ? that.city.areaName : "", rec.countyId) {
                      var camelKey = self.getObjectList(key, "pid", that.city.id);
                      that.country = self.fnCheckGtoreQty(camelKey, "id", rec.countyId);
                      str += that.country && that.country.areaName ? that.country.areaName : "";
                    }
                  }
                  str += rec.address ? rec.address : "";
                  /** @type {string} */
                  part = str;
                  if (part) {
                    if (part.length > 0) {
                      /** @type {string} */
                      part = part.replace(/[\r\n]/g, "");
                    }
                  }
                  article.content += find(suiteView, data, requestUrl, url, comment, rest, part, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
                  res.push(article);
                }
              }
            }
            result.resolve(res);
          });
        }).error(function() {
          console.error("服务器获取数据出现异常！");
          result.reject();
        });
      } else {
        db.post("/KEY160?ordersSn=" + name).success(function(item) {
          /**
           * @return {?}
           */
          function fetch() {
            var imageDfd = $q.defer();
            var request1 = db.httpCacheGet.get(db.httpCacheGet.ac.AllArea);
            return $q.all([request1]).then(function(image) {
              imageDfd.resolve(image);
            }, function() {
              imageDfd.reject();
            }), imageDfd.promise;
          }
          if (null == item) {
            return self.toastShow("没有数据"), result.reject(), result.promise;
          }
          var file = {
            title : "\n",
            content : "",
            total : "",
            footer : "",
            qrCode : {
              text : "",
              slogan : "",
              enable : false
            },
            printTpl : "ep-basic"
          };
          /** @type {string} */
          var data = "";
          /** @type {string} */
          var url = "";
          /** @type {string} */
          var requestUrl = "";
          if (options.name) {
            data = options.name;
          } else {
            if (config.comName) {
              data = config.comName;
            }
          }
          if (data) {
            if (data.length > 0) {
              /** @type {string} */
              data = data.replace(/[\r\n]/g, "");
            }
          }
          if (options.address) {
            url = options.address;
          } else {
            if (config.address) {
              url = config.address;
            }
          }
          if (url) {
            if (url.length > 0) {
              /** @type {string} */
              url = url.replace(/[\r\n]/g, "");
            }
          }
          if (options.phone) {
            requestUrl = options.phone;
          } else {
            if (config.phone) {
              requestUrl = config.phone;
            }
          }
          if (requestUrl) {
            if (requestUrl.length > 0) {
              /** @type {string} */
              requestUrl = requestUrl.replace(/[\r\n]/g, "");
            }
          }
          /** @type {string} */
          var comment = "";
          /** @type {string} */
          var part = "";
          /** @type {string} */
          var rest = "";
          if (comment = item.order.clientName ? item.order.clientName : "", comment && (comment.length > 0 && (comment = comment.replace(/[\r\n]/g, ""))), rest = item.order.cellPhone ? item.order.cellPhone : "", rest && (rest.length > 0 && (rest = rest.replace(/[\r\n]/g, ""))), fmt && fmt.indexOf("remark") > -1) {
            var failureMessage = item.order.remark ? item.order.remark : ""
          }
          if (item.orderDelivery && (4 == item.orderDelivery.deliveryType && item.orderDelivery.toPoint)) {
            part = item.orderDelivery.toPoint;
            if (part) {
              if (part.length > 0) {
                part = part.replace(/[\r\n]/g, "");
              }
            }
            file.content += find(suiteView, data, requestUrl, url, comment, rest, part, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
            result.resolve([file]);
          } else {
            /** @type {Array} */
            var key = [];
            fetch().then(function(packs) {
              key = packs[0].data;
              var value = self.getObjectList(key, "pid", 0);
              /** @type {string} */
              var str = "";
              var that = {};
              db.post("/KEY032?id=" + item.order.clientId).success(function(r) {
                var rec = r.objClient;
                if (rec.provinceId && (that.province = self.fnCheckGtoreQty(value, "id", rec.provinceId), str += that.province && that.province.areaName ? that.province.areaName : "", rec.cityId)) {
                  var node = self.getObjectList(key, "pid", that.province.id);
                  if (that.city = self.fnCheckGtoreQty(node, "id", rec.cityId), str += that.city && that.city.areaName ? that.city.areaName : "", rec.countyId) {
                    var camelKey = self.getObjectList(key, "pid", that.city.id);
                    that.country = self.fnCheckGtoreQty(camelKey, "id", rec.countyId);
                    str += that.country && that.country.areaName ? that.country.areaName : "";
                  }
                }
                str += rec.address ? rec.address : "";
                part = str;
                if (part) {
                  if (part.length > 0) {
                    part = part.replace(/[\r\n]/g, "");
                  }
                }
                file.content += find(suiteView, data, requestUrl, url, comment, rest, part, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
                result.resolve([file]);
              }).error(function() {
                file.content += find(suiteView, data, requestUrl, url, comment, rest, part, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
                result.resolve([file]);
              });
            });
          }
        }).error(function() {
          console.error("服务器获取数据出现异常！");
          result.reject();
        });
      }
    }).error(function() {
      console.error("从服务器获取打印设置数据出现异常！");
      result.reject();
    }), result.promise;
  }
  /**
   * @param {string} reviver
   * @param {string} it
   * @param {Function} path
   * @return {?}
   */
  function parse(reviver, it, path) {
    var defer = $q.defer();
    return path = ide.logisticsOrder, db.httpCacheGet.get("/KEY119?orderType=" + path).success(function(mockObject) {
      /** @type {number} */
      JSpec.localStorage["PrintTimes" + path] = 1;
      /** @type {string} */
      JSpec.localStorage["PrintSize" + path] = "ep-basic";
      var r;
      var failuresLink;
      var suiteView;
      var fmt;
      /** @type {boolean} */
      var d = false;
      var senderPhoneX = {
        senderNameX : 3,
        senderNameY : 5,
        senderNameW : 25,
        senderAddressX : 3,
        senderAddressY : 7,
        senderAddressW : 35,
        senderPhoneX : 3,
        senderPhoneY : 12,
        senderPhoneW : 12,
        receiverNameX : 53,
        receiverNameY : 5,
        receiverNameW : 25,
        receiverAddressX : 53,
        receiverAddressY : 7,
        receiverAddressW : 35,
        receiverPhoneX : 53,
        receiverPhoneY : 12,
        receiverPhoneW : 12,
        remarkX : 2,
        remarkY : 14,
        remarkW : 18
      };
      if (mockObject.object) {
        try {
          /** @type {*} */
          failuresLink = mockObject.object.footerText ? JSON.parse(mockObject.object.footerText) : senderPhoneX;
        } catch (g) {
          failuresLink = senderPhoneX;
        }
        suiteView = mockObject.object.printType;
        fmt = mockObject.object.selectColumnNames.split(",");
        /** @type {boolean} */
        d = true;
        if (mockObject.object.printTimes) {
          JSpec.localStorage["PrintTimes" + path] = mockObject.object.printTimes;
        }
      } else {
        r = {};
        failuresLink = senderPhoneX;
      }
      if (!(it.length > 0)) {
        return self.toastShow("没有数据"), defer.reject(), defer.promise;
      }
      /** @type {string} */
      var codeSegments = it;
      /** @type {Array} */
      var res = [];
      /** @type {number} */
      var i = 0;
      for (;i < codeSegments.length;i++) {
        var article = {
          title : "\n",
          content : "",
          total : "",
          footer : "",
          qrCode : {
            text : "",
            slogan : "",
            enable : false
          },
          printTpl : "ep-basic"
        };
        /** @type {string} */
        var qs = "";
        /** @type {string} */
        var q = "";
        /** @type {string} */
        var requestUrl = "";
        qs = codeSegments[i].senderName ? codeSegments[i].senderName : "";
        if (qs) {
          if (qs.length > 0) {
            qs = qs.replace(/[\r\n]/g, "");
          }
        }
        q = codeSegments[i].senderAddress ? codeSegments[i].senderAddress : "";
        if (q) {
          if (q.length > 0) {
            q = q.replace(/[\r\n]/g, "");
          }
        }
        requestUrl = codeSegments[i].senderPhone ? codeSegments[i].senderPhone : "";
        if (requestUrl) {
          if (requestUrl.length > 0) {
            requestUrl = requestUrl.replace(/[\r\n]/g, "");
          }
        }
        /** @type {string} */
        var comment = "";
        /** @type {string} */
        var rest = "";
        /** @type {string} */
        var desc = "";
        if (comment = codeSegments[i].receiverName ? codeSegments[i].receiverName : "", comment && (comment.length > 0 && (comment = comment.replace(/[\r\n]/g, ""))), desc = codeSegments[i].receiverPhone ? codeSegments[i].receiverPhone : "", desc && (desc.length > 0 && (desc = desc.replace(/[\r\n]/g, ""))), fmt && fmt.indexOf("remark") > -1) {
          var failureMessage = codeSegments[i].remark ? codeSegments[i].remark : ""
        }
        rest = codeSegments[i].receiverAddress ? codeSegments[i].receiverAddress : "";
        if (rest) {
          if (rest.length > 0) {
            rest = rest.replace(/[\r\n]/g, "");
          }
        }
        article.content += find(suiteView, qs, requestUrl, q, comment, desc, rest, failureMessage, fmt && fmt.indexOf("remark") > -1, fmt && fmt.indexOf("date") > -1, failuresLink);
        res.push(article);
      }
      defer.resolve(res);
    }).error(function() {
      console.error("从服务器获取打印设置数据出现异常！");
      defer.reject();
    }), defer.promise;
  }
  /**
   * @param {string} obj
   * @param {string} str
   * @param {string} val
   * @param {string} query
   * @param {string} value
   * @param {string} name
   * @param {string} key
   * @param {?} a
   * @param {?} seed
   * @param {?} results
   * @param {?} el
   * @return {?}
   */
  function find(obj, str, val, query, value, name, key, a, seed, results, el) {
    /**
     * @return {undefined}
     */
    function onSuccess() {
      if (seed) {
        result.push(data.remark);
      }
      if (results) {
        result.push(data.date);
      }
    }
    /**
     * @param {Array} arr
     * @return {undefined}
     */
    function collect(arr) {
      /** @type {number} */
      var j = 0;
      for (;j < arr.length - 1;j++) {
        /** @type {number} */
        var i = j + 1;
        for (;i < arr.length;i++) {
          if (fn(arr[i], arr[j])) {
            var tmp = arr[i];
            arr[i] = arr[j];
            arr[j] = tmp;
          }
        }
      }
    }
    /**
     * @param {?} a
     * @param {?} b
     * @return {?}
     */
    function fn(a, b) {
      return a.y - b.y < 0 || a.y == b.y && a.x - b.x < 0;
    }
    /**
     * @return {?}
     */
    function mixIn() {
      return storage.length > 0;
    }
    /**
     * @param {number} evt
     * @param {Array} data
     * @return {undefined}
     */
    function emit(evt, data) {
      /** @type {number} */
      var i = 0;
      for (;i < data.length && evt - 1 > offset;i++) {
        /** @type {number} */
        var len = data[i].y - offset;
        /** @type {number} */
        var maxAllowed = 0;
        for (;len > maxAllowed;maxAllowed++) {
          html += "\n";
          offset += 1;
          /** @type {number} */
          d = 0;
        }
        /** @type {number} */
        var a = data[i].x - d;
        /** @type {number} */
        var b = 0;
        for (;a > b;b++) {
          html += " ";
          d += 1;
        }
        var append = insert(data[i]);
        html += append;
        d += self.getBytesLength(append);
      }
    }
    /**
     * @param {Object} target
     * @return {?}
     */
    function insert(target) {
      /** @type {string} */
      var optsData = "";
      /** @type {number} */
      var fromIndex = 0;
      var x = target.w;
      /** @type {number} */
      var i = 0;
      for (;i < target.text.length;i++) {
        var buf = target.text.charAt(i);
        var itemWidth = self.getBytesLength(buf);
        if (!(x - itemWidth > -1)) {
          break;
        }
        optsData += buf;
        fromIndex += 1;
        x -= itemWidth;
      }
      return fromIndex < target.text.length && storage.push({
        x : target.x,
        y : target.y + 1,
        w : target.w,
        text : target.text.substr(fromIndex)
      }), optsData;
    }
    /**
     * @return {?}
     */
    function set() {
      /** @type {number} */
      var i = 0;
      for (;i < result.length;i++) {
        if (0 == i || result[i].y != result[i - 1].y) {
          if (mixIn()) {
            emit(result[i].y, storage);
            /** @type {Array} */
            storage = [];
          }
          /** @type {number} */
          var len = result[i].y - offset;
          /** @type {number} */
          var maxAllowed = 0;
          for (;len > maxAllowed;maxAllowed++) {
            html += "\n";
            offset += 1;
            /** @type {number} */
            d = 0;
          }
          /** @type {number} */
          var b = 0;
          for (;b < result[i].x;b++) {
            html += " ";
            d += 1;
          }
          var append = insert(result[i]);
          html += append;
          d += self.getBytesLength(append);
        } else {
          if (result[i].y == result[i - 1].y) {
            /** @type {number} */
            var a = result[i].x - d;
            /** @type {number} */
            b = 0;
            for (;a > b;b++) {
              html += " ";
              d += 1;
            }
            append = insert(result[i]);
            html += append;
            d += self.getBytesLength(append);
          }
        }
      }
      return mixIn() && (emit(25, storage), storage = []), html;
    }
    /** @type {string} */
    var html = "";
    /** @type {number} */
    var d = 1;
    /** @type {number} */
    var offset = 1;
    /** @type {Array} */
    var storage = [];
    /** @type {Array} */
    var fileName = [{
      key : "ZTO",
      remark : {
        key : "remark",
        x : 2,
        y : 14,
        w : 18
      },
      date : {
        key : "date",
        x : 23,
        y : 23,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 3,
        y : 5,
        w : 25
      }, {
        key : "receiverName",
        x : 53,
        y : 5,
        w : 25
      }, {
        key : "senderAddress",
        x : 3,
        y : 7,
        w : 35
      }, {
        key : "receiverAddress",
        x : 53,
        y : 7,
        w : 35
      }, {
        key : "senderPhone",
        x : 3,
        y : 12,
        w : 15
      }, {
        key : "receiverPhone",
        x : 53,
        y : 12,
        w : 15
      }]
    }, {
      key : "YTO",
      remark : {
        key : "remark",
        x : 4,
        y : 15,
        w : 16
      },
      date : {
        key : "date",
        x : 48,
        y : 23,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 1,
        y : 4,
        w : 25
      }, {
        key : "receiverName",
        x : 51,
        y : 4,
        w : 25
      }, {
        key : "senderAddress",
        x : 1,
        y : 8,
        w : 35
      }, {
        key : "receiverAddress",
        x : 50,
        y : 8,
        w : 35
      }, {
        key : "senderPhone",
        x : 5,
        y : 11,
        w : 15
      }, {
        key : "receiverPhone",
        x : 55,
        y : 11,
        w : 15
      }]
    }, {
      key : "STO",
      remark : {
        key : "remark",
        x : 1,
        y : 15,
        w : 22
      },
      date : {
        key : "date",
        x : 0,
        y : 23,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 3,
        y : 5,
        w : 25
      }, {
        key : "receiverName",
        x : 53,
        y : 5,
        w : 25
      }, {
        key : "senderAddress",
        x : 3,
        y : 9,
        w : 35
      }, {
        key : "receiverAddress",
        x : 53,
        y : 9,
        w : 35
      }, {
        key : "senderPhone",
        x : 7,
        y : 13,
        w : 15
      }, {
        key : "receiverPhone",
        x : 55,
        y : 13,
        w : 15
      }]
    }, {
      key : "BEST",
      remark : {
        key : "remark",
        x : 1,
        y : 17,
        w : 18
      },
      date : {
        key : "date",
        x : 0,
        y : 23,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 3,
        y : 4,
        w : 25
      }, {
        key : "receiverName",
        x : 53,
        y : 4,
        w : 25
      }, {
        key : "senderAddress",
        x : 3,
        y : 8,
        w : 35
      }, {
        key : "receiverAddress",
        x : 53,
        y : 8,
        w : 35
      }, {
        key : "senderPhone",
        x : 25,
        y : 12,
        w : 15
      }, {
        key : "receiverPhone",
        x : 75,
        y : 12,
        w : 15
      }]
    }, {
      key : "YUNDA",
      remark : {
        key : "remark",
        x : 2,
        y : 19,
        w : 18
      },
      date : {
        key : "date",
        x : 0,
        y : 23,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 2,
        y : 5,
        w : 25
      }, {
        key : "receiverName",
        x : 48,
        y : 5,
        w : 25
      }, {
        key : "senderAddress",
        x : 2,
        y : 8,
        w : 35
      }, {
        key : "receiverAddress",
        x : 49,
        y : 8,
        w : 35
      }, {
        key : "senderPhone",
        x : 20,
        y : 12,
        w : 15
      }, {
        key : "receiverPhone",
        x : 69,
        y : 12,
        w : 15
      }]
    }, {
      key : "SF",
      remark : {
        key : "remark",
        x : 0,
        y : 19,
        w : 16
      },
      date : {
        key : "date",
        x : 0,
        y : 25,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 7,
        y : 6,
        w : 25
      }, {
        key : "senderAddress",
        x : 2,
        y : 7,
        w : 40
      }, {
        key : "senderPhone",
        x : 3,
        y : 9,
        w : 15
      }, {
        key : "receiverName",
        x : 7,
        y : 11,
        w : 25
      }, {
        key : "receiverAddress",
        x : 3,
        y : 12,
        w : 40
      }, {
        key : "receiverPhone",
        x : 3,
        y : 16,
        w : 15
      }]
    }, {
      key : "EMS",
      remark : {
        key : "remark",
        x : 3,
        y : 23,
        w : 18
      },
      date : {
        key : "date",
        x : 80,
        y : 10,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 3,
        y : 4,
        w : 25
      }, {
        key : "senderPhone",
        x : 25,
        y : 4,
        w : 15
      }, {
        key : "senderAddress",
        x : 3,
        y : 7,
        w : 40
      }, {
        key : "receiverName",
        x : 3,
        y : 12,
        w : 25
      }, {
        key : "receiverPhone",
        x : 25,
        y : 12,
        w : 15
      }, {
        key : "receiverAddress",
        x : 3,
        y : 15,
        w : 40
      }]
    }, {
      key : "Default",
      remark : {
        key : "remark",
        x : 2,
        y : 14,
        w : 18
      },
      date : {
        key : "date",
        x : 10,
        y : 25,
        w : 18
      },
      xywList : [{
        key : "senderName",
        x : 3,
        y : 5,
        w : 25
      }, {
        key : "receiverName",
        x : 53,
        y : 5,
        w : 25
      }, {
        key : "senderAddress",
        x : 3,
        y : 7,
        w : 35
      }, {
        key : "receiverAddress",
        x : 53,
        y : 7,
        w : 35
      }, {
        key : "senderPhone",
        x : 3,
        y : 12,
        w : 15
      }, {
        key : "receiverPhone",
        x : 53,
        y : 12,
        w : 15
      }]
    }];
    if (collection.commonConfig) {
      if (collection.commonConfig.expressModel) {
        fileName = collection.commonConfig.expressModel;
      }
    }
    /** @type {Array} */
    var result = [];
    var data = self.fnCheckGtoreQty(fileName, "key", obj);
    switch(data && data.xywList ? self.union(result, data.xywList) : (data = self.fnCheckGtoreQty(fileName, "key", "Default"), self.union(result, data.xywList)), self.fnCheckGtoreQty(result, "key", "senderName").text = str, self.fnCheckGtoreQty(result, "key", "receiverName").text = value, self.fnCheckGtoreQty(result, "key", "senderAddress").text = query, self.fnCheckGtoreQty(result,
    "key", "receiverAddress").text = key, self.fnCheckGtoreQty(result, "key", "senderPhone").text = val, self.fnCheckGtoreQty(result, "key", "receiverPhone").text = name, data.remark.text = a, data.date.text = self.dateFormat(new Date, "yyyy  MM  dd"), obj) {
      case "ZTO":
        onSuccess();
        break;
      case "YTO":
        onSuccess();
        break;
      case "STO":
        onSuccess();
        break;
      case "BEST":
        onSuccess();
        break;
      case "YUNDA":
        onSuccess();
        break;
      case "SF":
        onSuccess();
        break;
      case "EMS":
        onSuccess();
        collect(result);
        break;
      case "DIY":
        /** @type {Array} */
        result = [{
          key : "senderName",
          x : el.senderNameX,
          y : el.senderNameY,
          w : el.senderNameW,
          text : str
        }, {
          key : "senderAddress",
          x : el.senderAddressX,
          y : el.senderAddressY,
          w : el.senderAddressW,
          text : query
        }, {
          key : "senderPhone",
          x : el.senderPhoneX,
          y : el.senderPhoneY,
          w : el.senderPhoneW,
          text : val
        }, {
          key : "receiverName",
          x : el.receiverNameX,
          y : el.receiverNameY,
          w : el.receiverNameW,
          text : value
        }, {
          key : "receiverAddress",
          x : el.receiverAddressX,
          y : el.receiverAddressY,
          w : el.receiverAddressW,
          text : key
        }, {
          key : "receiverPhone",
          x : el.receiverPhoneX,
          y : el.receiverPhoneY,
          w : el.receiverPhoneW,
          text : name
        }];
        if (seed) {
          result.push({
            key : "remark",
            x : 2,
            y : 14,
            w : 18,
            text : data.remark.text
          });
        }
        if (results) {
          result.push({
            key : "date",
            x : 4,
            y : 25,
            w : 18,
            text : data.date.text
          });
        }
        collect(result);
        break;
      default:
        onSuccess();
        collect(result);
    }
    return set();
  }
  return{
    /** @type {Function} */
    orderType : ide,
    /** @type {function (?, ?): undefined} */
    bluetooth : log,
    /** @type {function (string, string, string, string, boolean): undefined} */
    connectBluetooth : run,
    /** @type {function (?, ?, Array, ?, (Object|string), boolean): undefined} */
    connectBluetoothForBarCode : init,
    /** @type {function (string, string, string, string, boolean): undefined} */
    connectBluetoothForExpress : initialize,
    /** @type {function (?, ?, string): undefined} */
    print : write,
    /** @type {function (?, ?, ?): undefined} */
    autoPrint : done,
    /** @type {function (string, string, string): ?} */
    getPrintData : next,
    /** @type {function (string, string, string, string, string, string, string, ?, ?, ?, ?): ?} */
    getLogisticsPrintData : find
  };
}]).factory("lbSlideData", ["$q", "$http", "ServerConfig", "Tools", function($q, $templateCache, dataAndEvents, index) {
  var imageDfd = $q.defer();
  /** @type {string} */
  var i = "main_pic.json";
  var excludes = index.getDeviceInfo();
  return excludes.indexOf("t1host") > -1 && (i = "main_pic_t1host.json"), $templateCache.get("http://app.xinbafar.com.cn:8080/business/mobile/" + i + "?random=" + index.getTimeStamp()).success(function(image) {
    imageDfd.resolve(image);
  }).error(function() {
    console.error("从服务器获取图片出现异常！");
    imageDfd.reject();
  }), imageDfd.promise;
}]).factory("BCSlideData", ["$q", "$http", "Tools", function($q, $templateCache, dataAndEvents) {
  var imageDfd = $q.defer();
  return $templateCache.get("http://app.xinbafar.com.cn:8080/business/cdn/res/business/KEY305/is/ad.json?random=" + dataAndEvents.getTimeStamp()).success(function(image) {
    imageDfd.resolve(image);
  }).error(function() {
    console.error("从服务器获取图片出现异常！");
    imageDfd.reject();
  }), imageDfd.promise;
}]).factory("lbBackdrop", ["$document", "$timeout", function(iframe, fix) {
  /**
   * @return {undefined}
   */
  function animate() {
    if (1 === ++a) {
      el.addClass("lb-visible");
      ionic.requestAnimationFrame(function() {
        if (a) {
          el.addClass("lb-active");
        }
      });
    }
  }
  /**
   * @return {undefined}
   */
  function handler() {
    if (0 === --a) {
      el.removeClass("lb-active");
      fix(function() {
        if (!a) {
          el.removeClass("lb-visible");
        }
      }, 400, false);
    }
  }
  /**
   * @return {?}
   */
  function getElement() {
    return el;
  }
  var el = angular.element('<div class="lb-backdrop">');
  /** @type {number} */
  var a = 0;
  return iframe[0].body.appendChild(el[0]), {
    /** @type {function (): undefined} */
    retain : animate,
    /** @type {function (): undefined} */
    release : handler,
    /** @type {function (): ?} */
    getElement : getElement
  };
}]).factory("showInstructionBackdrop", ["lbBackdrop", "$compile", "$templateCache", "$timeout", "$ionicPlatform", "$window", "ServerType", "Tools", function(b, cb, otherMap, ignoreMethodDoesntExist, srv, win, deepDataAndEvents, dataAndEvents) {
  /**
   * @return {undefined}
   */
  function close() {
    (callback || angular.noop)();
    b.release();
    b.getElement().children().remove();
  }
  /**
   * @param {boolean} expectedNumberOfNonCommentArgs
   * @param {string} key
   * @return {undefined}
   */
  function init(expectedNumberOfNonCommentArgs, key) {
    if (deepDataAndEvents.isEX() && !win.sessionStorage["ex_" + key] || !deepDataAndEvents.isEX() && !win.localStorage[key]) {
      b.retain();
      b.getElement().append(cb(otherMap.get(key))(expectedNumberOfNonCommentArgs));
      callback = srv.registerBackButtonAction(close, 700, "showInstructionBackdropButtonAction");
      if (deepDataAndEvents.isEX()) {
        if (!win.sessionStorage["ex_" + key]) {
          /** @type {boolean} */
          win.sessionStorage["ex_" + key] = true;
        }
      }
      if (!deepDataAndEvents.isEX()) {
        if (!win.localStorage[key]) {
          /** @type {boolean} */
          win.localStorage[key] = true;
        }
      }
    }
  }
  var callback = angular.noop;
  return{
    /** @type {function (boolean, string): undefined} */
    show : init,
    /** @type {function (): undefined} */
    hide : close
  };
}]).factory("pageDetail", ["$state", function(async) {
  /**
   * @param {string} result
   * @return {?}
   */
  function isValidCountry(result) {
    if (result) {
      if (result.indexOf("JH") >= 0) {
        return "进货单";
      }
      if (result.indexOf("JT") >= 0) {
        return "进货退货单";
      }
      if (result.indexOf("PF") >= 0) {
        return "销售单";
      }
      if (result.indexOf("TH") >= 0) {
        return "销售退货单";
      }
      if (result.indexOf("LS") >= 0) {
        return "零售单";
      }
      if (result.indexOf("PD") >= 0) {
        return "库存盘点单";
      }
      if (result.indexOf("DB") >= 0) {
        return "库存调拨单";
      }
      if (result.indexOf("SK") >= 0) {
        return "收款单";
      }
      if (result.indexOf("FK") >= 0) {
        return "付款单";
      }
      if (result.indexOf("JZ") >= 0) {
        return "记账单";
      }
      if (result.indexOf("CX") >= 0) {
        return "拆卸单";
      }
      if (result.indexOf("ZZ") >= 0) {
        return "组装单";
      }
    }
    return "其它";
  }
  /**
   * @param {Array} recurring
   * @param {string} cards
   * @return {undefined}
   */
  function reload(recurring, cards) {
    if (cards) {
      /** @type {string} */
      var reversed = "";
      /** @type {string} */
      var ordersSn = "ordersSn";
      if (cards.indexOf("JH") >= 0  || cards.indexOf("CG") >= 0) {
        /** @type {string} */
        reversed = "eventmenu.KEY188";
        /** @type {string} */
        ordersSn = "purchaseSn";
      } else {
        if (cards.indexOf("JT") >= 0 || cards.indexOf("CT") >= 0) {
          /** @type {string} */
          reversed = "eventmenu.KEY063";
          /** @type {string} */
          ordersSn = "purchaseSn";
        } else {
          if (cards.indexOf("PF") >= 0 || cards.indexOf("XS") >= 0) {
            /** @type {string} */
            reversed = "eventmenu.KEY260";
          } else {
            if (cards.indexOf("TH") >= 0 || cards.indexOf("XT") >= 0) {
              /** @type {string} */
              reversed = "eventmenu.KEY145";
            } else {
              if (cards.indexOf("LS") >= 0  || cards.indexOf("LT") >= 0) {
                /** @type {string} */
                reversed = "eventmenu.KEY215";
              } else {
                if (cards.indexOf("PD") >= 0 || cards.indexOf("PDD") >= 0) {
                  /** @type {string} */
                  reversed = "eventmenu.KEY256";
                  /** @type {string} */
                  ordersSn = "orderNo";
                } else {
                  if (cards.indexOf("DB") >= 0 || cards.indexOf("TD") >= 0  || cards.indexOf("BD") >= 0) {
                    /** @type {string} */
                    reversed = "eventmenu.KEY096";
                    /** @type {string} */
                    ordersSn = "orderNo";
                  }
                }
              }
            }
          }
        }
      }
      if (reversed.length > 0) {
        if ("ordersSn" === ordersSn) {
          async.go(reversed, {
            ordersSn : cards
          });
        } else {
          if ("purchaseSn" === ordersSn) {
            async.go(reversed, {
              purchaseSn : cards
            });
          } else {
            if ("orderNo" === ordersSn) {
              async.go(reversed, {
                orderNo : cards
              });
            }
          }
        }
      }
    }
  }
  return{
    /** @type {function (Array, string): undefined} */
    gotoDetail : reload,
    /** @type {function (string): ?} */
    getOrderType : isValidCountry
  };
}]).factory("commonDataInterface", ["$q", "$http", "psisServices", "ServerConfig", "Tools", function($q, $templateCache, _, current, dataAndEvents) {
  /**
   * @param {?} stat
   * @param {?} stmt
   * @return {?}
   */
  function FgetGoodsStoredCount(stat, stmt) {
    var imageDfd = $q.defer();
    return _.postEncode("/KEY092", {
      goodsSn : stat,
      storehouseId : stmt
    }).success(function(errors) {
      imageDfd.resolve(errors.length ? errors : void 0);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {Array} val
   * @return {?}
   */
  function FgetGoodsListStoredCount(val) {
    var imageDfd = $q.defer();
    return _.postEncode("/KEY204", {
      goodsList : angular.toJson(val)
    }).success(function(errors) {
      imageDfd.resolve(errors.length ? errors : void 0);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {?} object
   * @return {?}
   */
  function error(object) {
    var imageDfd = $q.defer();
    return null != object ? (_.postEncode("/KEY372", {
      goodsId : object
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      imageDfd.reject();
    }), imageDfd.promise) : (imageDfd.reject(), imageDfd.promise);
  }
  /**
   * @param {string} resolvedValue
   * @return {?}
   */
  function FgetGoodsByGoodsSn(resolvedValue) {
    var imageDfd = $q.defer();
    return null != resolvedValue ? (_.postEncode("/KEY372", {
      goodsSn : resolvedValue
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      imageDfd.reject();
    }), imageDfd.promise) : (imageDfd.reject(), imageDfd.promise);
  }
  /**
   * @param {string} arr
   * @param {boolean} dataAndEvents
   * @param {number} signal_eof
   * @return {?}
   */
  function FgetGoodsByBarCode(arr, dataAndEvents, signal_eof) {
    /** @type {boolean} */
    dataAndEvents = true;
    var imageDfd = $q.defer();
    if (null != arr) {
      var attributes = {
        barCode : arr
      };
      return signal_eof > 0 && (attributes = {
        barCode : arr,
        storehouseId : signal_eof
      }), _.postEncode("/KEY372", attributes).success(function(image) {
        if (image) {
          imageDfd.resolve(image);
        } else {
          if (dataAndEvents) {
            _.postEncode("/KEY233", {
              page : 1,
              searchKey : arr
            }).success(function(column) {
              imageDfd.resolve(column.optionList.length > 0 ? column.optionList[0] : null);
            }).error(function() {
              console.error("服务器获取数据出现异常！");
              imageDfd.reject();
            });
          } else {
            console.error("服务器获取数据出现异常！");
            imageDfd.reject();
          }
        }
      }).error(function() {
        console.error("服务器获取数据出现异常！");
        imageDfd.reject();
      }), imageDfd.promise;
    }
    return imageDfd.reject(), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetAllColorSize() {
    var imageDfd = $q.defer();
    var request1 = _.httpCacheGet.get(_.httpCacheGet.ac.ALLCOLORLIST);
    var getPromise3 = _.httpCacheGet.get(_.httpCacheGet.ac.ALLSIZELIST);
    return $q.all([request1, getPromise3]).then(function(image) {
      imageDfd.resolve(image);
    }, function() {
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetModuleVersionData() {
    var deferred = $q.defer();
    var i = current.currentServer.replace("/is", "").replace("ex.", "www.").replace("web.", "www.");
    return $templateCache.get(i + "/download/data/dataVersion.json?random=" + dataAndEvents.getTimeStamp()).success(function(valid) {
      deferred.resolve(valid ? valid : void 0);
    }).error(function() {
      console.error("从服务器获取数据[getModuleVersionData]出现异常！");
      var translation = {
        vaServiceCode : "2015101010",
        recommendCode : "2015101010",
        versionUpdateCode : "2015101010"
      };
      deferred.resolve(translation);
    }), deferred.promise;
  }
  /**
   * @param {string} username
   * @param {number} key
   * @return {?}
   */
  function FgetUserConfig(username, key) {
    var imageDfd = $q.defer();
    return void 0 === key && (key = 2), _.post("/KEY246", {
      configKey : username,
      device : key
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("服务器获取数据出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetAllUserConfig() {
    var imageDfd = $q.defer();
    return _.post("/KEY231", {
      device : 2
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取用户配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetAllCompanyConfig() {
    var imageDfd = $q.defer();
    return _.post("/KEY229").success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取公司配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetCommonConfigs() {
    var imageDfd = $q.defer();
    var i = current.currentServer.replace("/is", "").replace("ex.", "www.").replace("web.", "www.");
    return $templateCache.get(i + "/download/data/commonConfig.json?random=" + dataAndEvents.getTimeStamp()).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取移动端公共配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetActivityConfig() {
    var imageDfd = $q.defer();
    var i = current.currentServer.replace("/is", "").replace("ex.", "www.").replace("web.", "www.");
    return $templateCache.get(i + "/download/data/activityConfig.json?random=" + dataAndEvents.getTimeStamp()).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取移动端活动配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetIAPProducts() {
    var imageDfd = $q.defer();
    var i = current.currentServer.replace("/is", "").replace("ex.", "www.").replace("web.", "www.");
    return $templateCache.get(i + "/download/IAP_products.json?random=" + dataAndEvents.getTimeStamp()).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取移动端活动配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function FgetPayConfigs() {
    var imageDfd = $q.defer();
    return _.post("/KEY232").success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("从服务器获取移动端扫码支付配置信息出现异常！");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {string} config
   * @param {string} opt_noCache
   * @param {number} opt_attributes
   * @return {?}
   */
  function FSaveUpdateUserConfig(config, opt_noCache, opt_attributes) {
    var imageDfd = $q.defer();
    return void 0 === opt_attributes && (opt_attributes = 2), _.post("/KEY245", {
      configKey : config,
      configValue : opt_noCache,
      device : opt_attributes
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("saveOrUpdateUserConfig error");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {?} h
   * @param {?} container
   * @param {number} opt_attributes
   * @return {?}
   */
  function initialize(h, container, opt_attributes) {
    var imageDfd = $q.defer();
    return _.post("/KEY165", {
      content : h,
      ordersSn : container,
      type : opt_attributes
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("saveOrUpdatePostil error");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {?} deepDataAndEvents
   * @return {?}
   */
  function to$q(deepDataAndEvents) {
    var imageDfd = $q.defer();
    return _.post("/KEY424", {
      id : deepDataAndEvents
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("deletePostil error");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {?} allBindingsAccessor
   * @param {string} val
   * @param {?} stopHere
   * @param {string} bytes
   * @return {?}
   */
  function update(allBindingsAccessor, val, stopHere, bytes) {
    var imageDfd = $q.defer();
    return _.postEncode("/KEY446", {
      msgContent : allBindingsAccessor,
      title : val,
      userIds : stopHere,
      extra : bytes
    }).success(function(image) {
      imageDfd.resolve(image);
    }).error(function() {
      console.error("sendNoBadgePush error");
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @param {string} jumpToNext
   * @param {string} error
   * @param {Object} text
   * @return {undefined}
   */
  function exec(jumpToNext, error, text) {
    _.post("/KEY421", {
      funId : jumpToNext,
      description : error,
      source : text
    }).success(function(r) {
      return r && 1 == r.statusCode;
    }).error(function() {
      return console.error("funLogInsert error"), false;
    });
  }
  return{
    /** @type {function (?, ?): ?} */
    getGoodsStoredCount : FgetGoodsStoredCount,
    /** @type {function (Array): ?} */
    getGoodsListStoredCount : FgetGoodsListStoredCount,
    /** @type {function (?): ?} */
    getGoodsById : error,
    /** @type {function (string): ?} */
    getGoodsByGoodsSn : FgetGoodsByGoodsSn,
    /** @type {function (string, boolean, number): ?} */
    getGoodsByBarCode : FgetGoodsByBarCode,
    /** @type {function (): ?} */
    getAllColorSize : FgetAllColorSize,
    /** @type {function (): ?} */
    getModuleVersionData : FgetModuleVersionData,
    /** @type {function (string, number): ?} */
    getUserConfig : FgetUserConfig,
    /** @type {function (): ?} */
    getAllUserConfig : FgetAllUserConfig,
    /** @type {function (): ?} */
    getAllCompanyConfig : FgetAllCompanyConfig,
    /** @type {function (): ?} */
    getCommonConfigs : FgetCommonConfigs,
    /** @type {function (): ?} */
    getActivityConfig : FgetActivityConfig,
    /** @type {function (): ?} */
    getIAPProducts : FgetIAPProducts,
    /** @type {function (): ?} */
    getPayConfigs : FgetPayConfigs,
    /** @type {function (string, string, number): ?} */
    saveOrUpdateUserConfig : FSaveUpdateUserConfig,
    /** @type {function (?, ?, number): ?} */
    saveOrUpdatePostil : initialize,
    /** @type {function (?): ?} */
    deletePostil : to$q,
    /** @type {function (?, string, ?, string): ?} */
    sendNoBadgePush : update,
    /** @type {function (string, string, Object): undefined} */
    addFuncLog : exec
  };
}]).factory("ContactsService", ["$q", function($q) {
  return{
    /**
     * @param {Function} id
     * @return {?}
     */
    find : function(id) {
      var defer = $q.defer();
      var obj = new ContactFindOptions;
      /** @type {Function} */
      obj.filter = id;
      /** @type {boolean} */
      obj.multiple = true;
      /** @type {Array} */
      var fields = ["displayName", "name", "phoneNumbers"];
      return navigator.contacts.find(fields, function(val) {
        defer.resolve(val);
      }, function(error) {
        defer.reject(error);
      }, obj), defer.promise;
    }
  };
}]).factory("BTScanerService", ["$window", "$timeout", "Tools", function($window, jQuery, dataAndEvents) {
  /**
   * @param {Function} val
   * @param {?} handler
   * @return {undefined}
   */
  function _init(val, handler) {
    if (window.plugins && BC) {
      var uid = $window.localStorage.blueScaner;
      if (handler) {
        handler = BC.bluetooth.devices[handler.deviceAddress];
      } else {
        if (uid) {
          handler = BC.bluetooth.devices[uid];
        }
      }
      if (handler) {
        if (handler.isConnected) {
          bind(val, handler);
        } else {
          if (ionic.Platform.isAndroid()) {
            handler.connect(function() {
              dataAndEvents.toastShow("蓝牙扫码枪连接成功");
              bind(val, handler);
            }, function() {
              console.log("蓝牙扫码枪连接失败");
            }, "00001101-0000-1000-8000-00805F9B34FB", true);
          } else {
            handler.connect(function() {
              dataAndEvents.toastShow("蓝牙扫码枪连接成功");
              bind(val, handler);
            }, function() {
              console.log("蓝牙扫码枪连接失败");
            });
          }
        }
      }
    }
  }
  /**
   * @param {Function} cb
   * @param {?} options
   * @return {undefined}
   */
  function bind(cb, options) {
    /** @type {string} */
    var out = "";
    /**
     * @param {string} range
     * @return {undefined}
     */
    var fn = function(range) {
      jQuery(function() {
        if ("function" == typeof cb) {
          cb(range.trim());
        }
        /** @type {string} */
        out = "";
      });
    };
    var callback = ionic.debounce(fn, 100);
    if (ionic.Platform.isAndroid()) {
      options.rfcommSubscribe(function($provide) {
        var data = $provide.value.getASCIIString();
        if (data) {
          if (0 != data) {
            if (" " != data) {
              out += data;
              callback(out);
            }
          }
        }
      });
    } else {
      /** @type {string} */
      var core_rnotwhite = "18F0";
      /** @type {string} */
      var rSlash = "2AF0";
      options.discoverServices(function() {
        var s = options.getServiceByUUID(core_rnotwhite)[0];
        s.discoverCharacteristics(function() {
          s.getCharacteristicByUUID(rSlash)[0].subscribe(function($provide) {
            var data = $provide.value.getASCIIString();
            if (data) {
              if (0 != data) {
                if (" " != data) {
                  out += data;
                  callback(out);
                }
              }
            }
          });
        });
      });
    }
  }
  return{
    /** @type {function (Function, ?): undefined} */
    getScanerCode : _init
  };
}]).factory("HandleMessageService", ["$timeout", "Tools", "$ionicPopup", "$state", "InAppStorePurchase", function(dataAndEvents, eventUtil, $window, $state, _socket) {
  /**
   * @param {Object} event
   * @param {?} scope
   * @return {undefined}
   */
  function fn(event, scope) {
    if (event.data.actionCallMethod && eval(event.data.actionCallMethod), "openAppSuccess" == event.data.actionType) {
      scope.refreshAccRecource();
      if (5 == event.data.object.appId || 3 == event.data.object.appId) {
        scope.getCompanyConfigs();
      } else {
        if (4 == event.data.object.appId) {
          scope.getPayConfigs();
        }
      }
    } else {
      if ("openServiceSuccess" == event.data.actionType) {
        scope.goBack();
      } else {
        if ("openAlipay" == event.data.actionType) {
          eventUtil.handleApliPayMsg(event);
        } else {
          if ("openWxpay" == event.data.actionType) {
            eventUtil.handleWxpayMsg(event);
          } else {
            if ("openIAP" == event.data.actionType) {
              _socket.handleIAPMsg(event);
            } else {
              if ("getAppVersion" == event.data.actionType) {
                var appVersion = scope.getInnerAppVersion();
                event.source.postMessage({
                  actionType : "returnAppVersion",
                  appVersion : appVersion
                }, "*");
              } else {
                if ("goState" == event.data.actionType) {
                  if (event.data.object.goBack) {
                    scope.goBack();
                  } else {
                    $state.go(event.data.object.state);
                  }
                } else {
                  if ("openInApp" == event.data.actionType) {
                    scope.openLink(event.data.object.url, 1);
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return{
    /** @type {function (Object, ?): undefined} */
    handleMessage : fn
  };
}]).factory("InAppStorePurchase", ["Tools", "lbSpinnerDialog", "ServerConfig", "commonDataInterface", "$q", function(i18n, loading, dataAndEvents, deepDataAndEvents, $q) {
  /**
   * @return {?}
   */
  function resolve() {
    var imageDfd = $q.defer();
    if (!window.cordova || !store) {
      return imageDfd.reject(), imageDfd.promise;
    }
    /** @type {Array} */
    var typePattern = [{
      id : "2000001",
      alias : "6个月客户积分",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2100001",
      alias : "6个月进销存会员",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2200001",
      alias : "6个月销货宝",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2300001",
      alias : "6个月扫码支付",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2000002",
      alias : "1年客户积分",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2100002",
      alias : "1年进销存会员",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2200002",
      alias : "1年销货宝",
      type : store.NON_RENEWING_SUBSCRIPTION
    }, {
      id : "2300002",
      alias : "1年扫码支付",
      type : store.NON_RENEWING_SUBSCRIPTION
    }];
    return deepDataAndEvents.getIAPProducts().then(function(newlines) {
      if (newlines) {
        if (newlines.length > 0) {
          /** @type {Array} */
          typePattern = newlines;
        }
      }
      run(typePattern);
      imageDfd.resolve();
    }, function() {
      run(typePattern);
      imageDfd.resolve();
    }), imageDfd.promise;
  }
  /**
   * @param {Array} args
   * @return {undefined}
   */
  function run(args) {
    /** @type {string} */
    store.validator = dataAndEvents.mgrServer + "/KEY422";
    /** @type {number} */
    var i = 0;
    var len = args.length;
    for (;len > i;i++) {
      store.register(args[i]);
    }
    store.when("product").approved(function(worker) {
      loading.hide();
      console.log("支付结果验证中..");
      loading.show();
      worker.verify().success(function(dataAndEvents, _fn) {
        i18n.toastShow("已成功购买" + _fn.alias);
        loading.hide();
      }).error(function() {
        i18n.toastShow("支付验证过程中出错");
        loading.hide();
      });
    });
    store.when("product").verified(function(test) {
      test.finish();
      loading.hide();
      hide(1, "IAP支付完成");
      i18n.toastShow("支付完成");
    });
    store.when("product").unverified(function() {
      loading.hide();
      hide(0, "不合法的支付");
      i18n.toastShow("不合法的支付");
    });
    store.when("product").error(function(error) {
      loading.hide();
      console.log("ERROR " + error.code + ": " + error.message);
      hide(0, "ERROR " + error.code + ": " + error.message);
      i18n.toastShow(error.message);
    });
    store.when("product").cancelled(function() {
      loading.hide();
      hide(0, "支付已取消");
      i18n.toastShow("支付已取消");
    });
    store.ready(function() {
      console.log("内购已准备就绪");
    });
    store.refresh();
  }
  /**
   * @param {string} attributes
   * @return {undefined}
   */
  function initialize(attributes) {
    resolve().then(function() {
      attributes = attributes ? attributes : "10000060";
      store.order(attributes);
      loading.show(true);
    });
  }
  /**
   * @param {Function} recurring
   * @param {string} h
   * @return {undefined}
   */
  function hide(recurring, h) {
    document.getElementById("apliPayiFrame").contentWindow.postMessage({
      /** @type {Function} */
      statusCode : recurring,
      content : h,
      actionType : "IAPResult"
    }, "*");
  }
  /**
   * @param {Object} options
   * @return {undefined}
   */
  function create(options) {
    console.log(options.data);
    if (1 == options.data.statusCode) {
      if (options.data.object) {
        if (store) {
          initialize(options.data.object.iapProductId);
        }
      }
    }
  }
  return{
    /** @type {function (): ?} */
    initializeStore : resolve,
    /** @type {function (string): undefined} */
    purchase : initialize,
    /** @type {function (Object): undefined} */
    handleIAPMsg : create
  };
}]).factory("GestureLockService", [function() {
  /**
   * @param {Object} self
   * @param {Object} e
   * @return {undefined}
   */
  function run(self, e) {
    if ("function" == typeof self.gestureStart) {
      self.gestureStart.call(self, e);
    }
    var pos = position(e);
    /** @type {number} */
    var i = 0;
    for (;i < self.activityPoints.length;i++) {
      if (Math.abs(pos.x - self.activityPoints[i].x) < self.radii && Math.abs(pos.y - self.activityPoints[i].y) < self.radii) {
        self.cipherPoints.push(self.activityPoints[i]);
        self.activityPoints.splice(i, 1);
        update(self.context2d, self.cipherPoints, self.config.default.lineWidth, self.config.default.lineStrokeStyle);
        $(self.context2d, self.cipherPoints, self.radii / 2, self.config.default.pointStrokeStyle);
        break;
      }
    }
  }
  /**
   * @param {Object} self
   * @param {?} event
   * @return {undefined}
   */
  function draw(self, event) {
    if ("function" == typeof self.gestureChange) {
      self.gestureChange.call(self, event);
    }
    var pos = position(event);
    /** @type {number} */
    var i = 0;
    for (;i < self.activityPoints.length;i++) {
      if (Math.abs(pos.x - self.activityPoints[i].x) < self.radii && Math.abs(pos.y - self.activityPoints[i].y) < self.radii) {
        self.cipherPoints.push(self.activityPoints[i]);
        self.activityPoints.splice(i, 1);
        if ("function" == typeof self.gesturePointChange) {
          self.gesturePointChange.call(self, event);
        }
        break;
      }
    }
    self.context2d.clearRect(0, 0, self.canvas.width, self.canvas.height);
    callback(self.context2d, self.originalPoints, self.radii, self.config.default.ringWidth, self.config.default.ringStrokeStyle);
    update(self.context2d, self.cipherPoints.concat(pos), self.config.default.lineWidth, self.config.default.lineStrokeStyle);
    $(self.context2d, self.cipherPoints, self.radii / 2, self.config.default.pointStrokeStyle);
  }
  /**
   * @param {Object} self
   * @param {?} obj
   * @return {undefined}
   */
  function loop(self, obj) {
    self.context2d.clearRect(0, 0, self.canvas.width, self.canvas.height);
    callback(self.context2d, self.originalPoints, self.radii, self.config.default.ringWidth, self.config.default.ringStrokeStyle);
    update(self.context2d, self.cipherPoints, self.config.default.lineWidth, self.config.default.lineStrokeStyle);
    $(self.context2d, self.cipherPoints, self.radii / 2, self.config.default.pointStrokeStyle);
    if ("function" == typeof self.gestureEnd) {
      self.gestureEnd.call(self, obj);
    }
  }
  /**
   * @param {CanvasRenderingContext2D} ctx
   * @param {?} force
   * @param {?} buf
   * @param {?} value
   * @param {?} s
   * @return {undefined}
   */
  var render = function(ctx, force, buf, value, s) {
    ctx.strokeStyle = s;
    ctx.lineWidth = value;
    ctx.beginPath();
    ctx.arc(force.x, force.y, buf, 0, 2 * Math.PI, true);
    ctx.closePath();
    ctx.stroke();
  };
  /**
   * @param {?} data
   * @param {Array} number
   * @param {?} chunk
   * @param {?} isXML
   * @param {?} args
   * @return {undefined}
   */
  var callback = function(data, number, chunk, isXML, args) {
    /** @type {number} */
    var i = 0;
    var n = number.length;
    for (;n > i;i++) {
      render(data, number[i], chunk, isXML, args);
    }
  };
  /**
   * @param {CanvasRenderingContext2D} ctx
   * @param {?} center
   * @param {number} r
   * @param {?} deepDataAndEvents
   * @return {undefined}
   */
  var drawCircle = function(ctx, center, r, deepDataAndEvents) {
    ctx.fillStyle = deepDataAndEvents;
    ctx.beginPath();
    ctx.arc(center.x, center.y, r, 0, 2 * Math.PI, true);
    ctx.closePath();
    ctx.fill();
  };
  /**
   * @param {?} context
   * @param {Array} all
   * @param {number} state
   * @param {?} deepDataAndEvents
   * @return {undefined}
   */
  var $ = function(context, all, state, deepDataAndEvents) {
    /** @type {number} */
    var packageDir = 0;
    var al = all.length;
    for (;al > packageDir;packageDir++) {
      drawCircle(context, all[packageDir], state, deepDataAndEvents);
    }
  };
  /**
   * @param {CanvasRenderingContext2D} ctx
   * @param {Array} coords
   * @param {?} left
   * @param {?} col
   * @return {undefined}
   */
  var update = function(ctx, coords, left, col) {
    ctx.strokeStyle = col;
    ctx.lineWidth = left;
    ctx.beginPath();
    /** @type {number} */
    var y = 0;
    var x = coords.length;
    for (;x > y;y++) {
      if (y > 0) {
        ctx.lineTo(coords[y].x, coords[y].y);
      } else {
        ctx.moveTo(coords[0].x, coords[0].y);
      }
    }
    ctx.stroke();
    ctx.closePath();
  };
  /**
   * @param {Object} event
   * @return {?}
   */
  var position = function(event) {
    var rect = event.currentTarget.getBoundingClientRect();
    return{
      x : event.touches[0].clientX - rect.left,
      y : event.touches[0].clientY - rect.top
    };
  };
  /**
   * @param {Object} self
   * @return {undefined}
   */
  var init = function(self) {
    document.addEventListener("touchmove", function(types) {
      types.preventDefault();
    }, false);
    self.canvas.addEventListener("touchstart", function(p) {
      p.preventDefault();
      if (!self.touchFlag) {
        if (!self.disabled) {
          /** @type {boolean} */
          self.touchFlag = true;
          /** @type {boolean} */
          self.disabled = true;
          run(self, p);
        }
      }
    }, false);
    self.canvas.addEventListener("touchmove", function(container) {
      if (self.touchFlag) {
        draw(self, container);
      }
    }, false);
    self.canvas.addEventListener("touchend", function(walkers) {
      if (self.touchFlag) {
        loop(self, walkers);
        /** @type {boolean} */
        self.touchFlag = false;
      }
    }, false);
  };
  /**
   * @param {HTMLElement} canvas
   * @param {Object} opts
   * @return {undefined}
   */
  var Game = function(canvas, opts) {
    var options = {
      success : {
        lineWidth : 6,
        lineStrokeStyle : "#fff",
        ringWidth : 1,
        ringStrokeStyle : "#00FF49",
        pointStrokeStyle : "#fff"
      },
      error : {
        lineWidth : 6,
        lineStrokeStyle : "#FF1200",
        ringWidth : 1,
        ringStrokeStyle : "#FF1200",
        pointStrokeStyle : "#FF1200"
      },
      warning : {
        lineWidth : 6,
        lineStrokeStyle : "#f0ad4e",
        ringWidth : 1,
        ringStrokeStyle : "#f0ad4e",
        pointStrokeStyle : "#f0ad4e"
      },
      "default" : {
        lineWidth : 6,
        lineStrokeStyle : "#fff",
        ringWidth : 1,
        ringStrokeStyle : "#fff",
        pointStrokeStyle : "#fff"
      },
      matrix : 3
    };
    this.gestureStart = void 0;
    this.gestureChange = void 0;
    this.gesturePointChange = void 0;
    this.gestureEnd = void 0;
    this.config = angular.extend(options, opts || {});
    /** @type {boolean} */
    this.touchFlag = false;
    /** @type {boolean} */
    this.disabled = false;
    /** @type {number} */
    this.radii = 0;
    /** @type {Array} */
    this.cipherPoints = [];
    /** @type {Array} */
    this.activityPoints = [];
    /** @type {Array} */
    this.originalPoints = [];
    /** @type {HTMLElement} */
    this.canvas = canvas;
    this.context2d = canvas.getContext("2d");
    init(this);
  };
  return Game.prototype.init = function() {
    var c = this.config.matrix;
    /** @type {number} */
    var idx = 0;
    /** @type {number} */
    this.radii = this.canvas.width / (4 * c);
    /** @type {Array} */
    this.originalPoints = [];
    /** @type {number} */
    var m22 = 0;
    var control = c;
    for (;control > m22;m22++) {
      /** @type {number} */
      var b = 0;
      var a = c;
      for (;a > b;b++) {
        idx++;
        var wrapper = {
          x : 4 * b * this.radii + 2 * this.radii,
          y : 4 * m22 * this.radii + 2 * this.radii,
          index : idx
        };
        this.originalPoints.push(wrapper);
      }
    }
    return this.reset(), this;
  }, Game.prototype.reset = function() {
    /** @type {Array} */
    this.activityPoints = [].concat(this.originalPoints);
    /** @type {Array} */
    this.cipherPoints = [];
    this.context2d.clearRect(0, 0, this.canvas.width, this.canvas.height);
    callback(this.context2d, this.originalPoints, this.radii, this.config.default.ringWidth, this.config.default.ringStrokeStyle);
    /** @type {boolean} */
    this.disabled = false;
  }, Game.prototype.viewStatus = function(name, opt_attributes) {
    var p = {
      ring : true,
      line : false,
      point : false
    };
    p = angular.extend(p, opt_attributes);
    if (p.ring) {
      callback(this.context2d, this.cipherPoints, this.radii, this.config[name].ringWidth, this.config[name].ringStrokeStyle);
    }
    if (p.line) {
      update(this.context2d, this.cipherPoints, this.config[name].lineWidth, this.config[name].lineStrokeStyle);
    }
    if (p.point) {
      $(this.context2d, this.cipherPoints, this.radii / 2, this.config[name].pointStrokeStyle);
    }
  }, Game.prototype.getGesturePassword = function() {
    return this.cipherPoints.map(function(pos) {
      return pos.index;
    });
  }, Game.prototype.validatePassword = function(x, y) {
    /** @type {boolean} */
    var validatePassword = true;
    if (!x || !y) {
      return false;
    }
    if (x.length != y.length) {
      return false;
    }
    /** @type {number} */
    var i = 0;
    var l = x.length;
    for (;l > i;i++) {
      if (x[i] !== y[i]) {
        /** @type {boolean} */
        validatePassword = false;
        break;
      }
    }
    return validatePassword;
  }, Game;
}]);
